Class: Aws::DataSync::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::DataSync::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-datasync/client.rb,
sig/client.rbs
Overview
An API client for DataSync. To construct a client, you need to configure a :region and :credentials.
client = Aws::DataSync::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CancelTaskExecutionResponseSuccess, _CreateAgentResponseSuccess, _CreateLocationAzureBlobResponseSuccess, _CreateLocationEfsResponseSuccess, _CreateLocationFsxLustreResponseSuccess, _CreateLocationFsxOntapResponseSuccess, _CreateLocationFsxOpenZfsResponseSuccess, _CreateLocationFsxWindowsResponseSuccess, _CreateLocationHdfsResponseSuccess, _CreateLocationNfsResponseSuccess, _CreateLocationObjectStorageResponseSuccess, _CreateLocationS3ResponseSuccess, _CreateLocationSmbResponseSuccess, _CreateTaskResponseSuccess, _DeleteAgentResponseSuccess, _DeleteLocationResponseSuccess, _DeleteTaskResponseSuccess, _DescribeAgentResponseSuccess, _DescribeLocationAzureBlobResponseSuccess, _DescribeLocationEfsResponseSuccess, _DescribeLocationFsxLustreResponseSuccess, _DescribeLocationFsxOntapResponseSuccess, _DescribeLocationFsxOpenZfsResponseSuccess, _DescribeLocationFsxWindowsResponseSuccess, _DescribeLocationHdfsResponseSuccess, _DescribeLocationNfsResponseSuccess, _DescribeLocationObjectStorageResponseSuccess, _DescribeLocationS3ResponseSuccess, _DescribeLocationSmbResponseSuccess, _DescribeTaskExecutionResponseSuccess, _DescribeTaskResponseSuccess, _ListAgentsResponseSuccess, _ListLocationsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTaskExecutionsResponseSuccess, _ListTasksResponseSuccess, _StartTaskExecutionResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateAgentResponseSuccess, _UpdateLocationAzureBlobResponseSuccess, _UpdateLocationEfsResponseSuccess, _UpdateLocationFsxLustreResponseSuccess, _UpdateLocationFsxOntapResponseSuccess, _UpdateLocationFsxOpenZfsResponseSuccess, _UpdateLocationFsxWindowsResponseSuccess, _UpdateLocationHdfsResponseSuccess, _UpdateLocationNfsResponseSuccess, _UpdateLocationObjectStorageResponseSuccess, _UpdateLocationS3ResponseSuccess, _UpdateLocationSmbResponseSuccess, _UpdateTaskExecutionResponseSuccess, _UpdateTaskResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_task_execution(params = {}) ⇒ Struct
Stops an DataSync task execution that's in progress.
-
#create_agent(params = {}) ⇒ Types::CreateAgentResponse
Activates an DataSync agent that you deploy in your storage environment.
-
#create_location_azure_blob(params = {}) ⇒ Types::CreateLocationAzureBlobResponse
Creates a transfer location for a Microsoft Azure Blob Storage container.
-
#create_location_efs(params = {}) ⇒ Types::CreateLocationEfsResponse
Creates a transfer location for an Amazon EFS file system.
-
#create_location_fsx_lustre(params = {}) ⇒ Types::CreateLocationFsxLustreResponse
Creates a transfer location for an Amazon FSx for Lustre file system.
-
#create_location_fsx_ontap(params = {}) ⇒ Types::CreateLocationFsxOntapResponse
Creates a transfer location for an Amazon FSx for NetApp ONTAP file system.
-
#create_location_fsx_open_zfs(params = {}) ⇒ Types::CreateLocationFsxOpenZfsResponse
Creates a transfer location for an Amazon FSx for OpenZFS file system.
-
#create_location_fsx_windows(params = {}) ⇒ Types::CreateLocationFsxWindowsResponse
Creates a transfer location for an Amazon FSx for Windows File Server file system.
-
#create_location_hdfs(params = {}) ⇒ Types::CreateLocationHdfsResponse
Creates a transfer location for a Hadoop Distributed File System (HDFS).
-
#create_location_nfs(params = {}) ⇒ Types::CreateLocationNfsResponse
Creates a transfer location for a Network File System (NFS) file server.
-
#create_location_object_storage(params = {}) ⇒ Types::CreateLocationObjectStorageResponse
Creates a transfer location for an object storage system.
-
#create_location_s3(params = {}) ⇒ Types::CreateLocationS3Response
Creates a transfer location for an Amazon S3 bucket.
-
#create_location_smb(params = {}) ⇒ Types::CreateLocationSmbResponse
Creates a transfer location for a Server Message Block (SMB) file server.
-
#create_task(params = {}) ⇒ Types::CreateTaskResponse
Configures a task, which defines where and how DataSync transfers your data.
-
#delete_agent(params = {}) ⇒ Struct
Removes an DataSync agent resource from your Amazon Web Services account.
-
#delete_location(params = {}) ⇒ Struct
Deletes a transfer location resource from DataSync.
-
#delete_task(params = {}) ⇒ Struct
Deletes a transfer task resource from DataSync.
-
#describe_agent(params = {}) ⇒ Types::DescribeAgentResponse
Returns information about an DataSync agent, such as its name, service endpoint type, and status.
-
#describe_location_azure_blob(params = {}) ⇒ Types::DescribeLocationAzureBlobResponse
Provides details about how an DataSync transfer location for Microsoft Azure Blob Storage is configured.
-
#describe_location_efs(params = {}) ⇒ Types::DescribeLocationEfsResponse
Provides details about how an DataSync transfer location for an Amazon EFS file system is configured.
-
#describe_location_fsx_lustre(params = {}) ⇒ Types::DescribeLocationFsxLustreResponse
Provides details about how an DataSync transfer location for an Amazon FSx for Lustre file system is configured.
-
#describe_location_fsx_ontap(params = {}) ⇒ Types::DescribeLocationFsxOntapResponse
Provides details about how an DataSync transfer location for an Amazon FSx for NetApp ONTAP file system is configured.
-
#describe_location_fsx_open_zfs(params = {}) ⇒ Types::DescribeLocationFsxOpenZfsResponse
Provides details about how an DataSync transfer location for an Amazon FSx for OpenZFS file system is configured.
-
#describe_location_fsx_windows(params = {}) ⇒ Types::DescribeLocationFsxWindowsResponse
Provides details about how an DataSync transfer location for an Amazon FSx for Windows File Server file system is configured.
-
#describe_location_hdfs(params = {}) ⇒ Types::DescribeLocationHdfsResponse
Provides details about how an DataSync transfer location for a Hadoop Distributed File System (HDFS) is configured.
-
#describe_location_nfs(params = {}) ⇒ Types::DescribeLocationNfsResponse
Provides details about how an DataSync transfer location for a Network File System (NFS) file server is configured.
-
#describe_location_object_storage(params = {}) ⇒ Types::DescribeLocationObjectStorageResponse
Provides details about how an DataSync transfer location for an object storage system is configured.
-
#describe_location_s3(params = {}) ⇒ Types::DescribeLocationS3Response
Provides details about how an DataSync transfer location for an S3 bucket is configured.
-
#describe_location_smb(params = {}) ⇒ Types::DescribeLocationSmbResponse
Provides details about how an DataSync transfer location for a Server Message Block (SMB) file server is configured.
-
#describe_task(params = {}) ⇒ Types::DescribeTaskResponse
Provides information about a task, which defines where and how DataSync transfers your data.
-
#describe_task_execution(params = {}) ⇒ Types::DescribeTaskExecutionResponse
Provides information about an execution of your DataSync task.
-
#list_agents(params = {}) ⇒ Types::ListAgentsResponse
Returns a list of DataSync agents that belong to an Amazon Web Services account in the Amazon Web Services Region specified in the request.
-
#list_locations(params = {}) ⇒ Types::ListLocationsResponse
Returns a list of source and destination locations.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns all the tags associated with an Amazon Web Services resource.
-
#list_task_executions(params = {}) ⇒ Types::ListTaskExecutionsResponse
Returns a list of executions for an DataSync transfer task.
-
#list_tasks(params = {}) ⇒ Types::ListTasksResponse
Returns a list of the DataSync tasks you created.
-
#start_task_execution(params = {}) ⇒ Types::StartTaskExecutionResponse
Starts an DataSync transfer task.
-
#tag_resource(params = {}) ⇒ Struct
Applies a tag to an Amazon Web Services resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from an Amazon Web Services resource.
-
#update_agent(params = {}) ⇒ Struct
Updates the name of an DataSync agent.
-
#update_location_azure_blob(params = {}) ⇒ Struct
Modifies the following configurations of the Microsoft Azure Blob Storage transfer location that you're using with DataSync.
-
#update_location_efs(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Amazon EFS transfer location that you're using with DataSync.
-
#update_location_fsx_lustre(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Amazon FSx for Lustre transfer location that you're using with DataSync.
-
#update_location_fsx_ontap(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Amazon FSx for NetApp ONTAP transfer location that you're using with DataSync.
-
#update_location_fsx_open_zfs(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Amazon FSx for OpenZFS transfer location that you're using with DataSync.
-
#update_location_fsx_windows(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Amazon FSx for Windows File Server transfer location that you're using with DataSync.
-
#update_location_hdfs(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Hadoop Distributed File System (HDFS) transfer location that you're using with DataSync.
-
#update_location_nfs(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Network File System (NFS) transfer location that you're using with DataSync.
-
#update_location_object_storage(params = {}) ⇒ Struct
Modifies the following configuration parameters of the object storage transfer location that you're using with DataSync.
-
#update_location_s3(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Amazon S3 transfer location that you're using with DataSync.
-
#update_location_smb(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Server Message Block (SMB) transfer location that you're using with DataSync.
-
#update_task(params = {}) ⇒ Struct
Updates the configuration of a task, which defines where and how DataSync transfers your data.
-
#update_task_execution(params = {}) ⇒ Struct
Updates the configuration of a running DataSync task execution.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-datasync/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5168 5169 5170 |
# File 'lib/aws-sdk-datasync/client.rb', line 5168 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5171 5172 5173 |
# File 'lib/aws-sdk-datasync/client.rb', line 5171 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 |
# File 'lib/aws-sdk-datasync/client.rb', line 5141 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::DataSync') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-datasync' context[:gem_version] = '1.126.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_task_execution(params = {}) ⇒ Struct
Stops an DataSync task execution that's in progress. The transfer of some files are abruptly interrupted. File contents that're transferred to the destination might be incomplete or inconsistent with the source files.
However, if you start a new task execution using the same task and allow it to finish, file content on the destination will be complete and consistent. This applies to other unexpected failures that interrupt a task execution. In all of these cases, DataSync successfully completes the transfer when you start the next task execution.
86 |
# File 'sig/client.rbs', line 86
def cancel_task_execution: (
|
#create_agent(params = {}) ⇒ Types::CreateAgentResponse
Activates an DataSync agent that you deploy in your storage environment. The activation process associates the agent with your Amazon Web Services account.
If you haven't deployed an agent yet, see Do I need a DataSync agent?
96 |
# File 'sig/client.rbs', line 96
def create_agent: (
|
#create_location_azure_blob(params = {}) ⇒ Types::CreateLocationAzureBlobResponse
Creates a transfer location for a Microsoft Azure Blob Storage container. DataSync can use this location as a transfer source or destination. You can make transfers with or without a DataSync agent that connects to your container.
Before you begin, make sure you know how DataSync accesses Azure Blob Storage and works with access tiers and blob types.
116 |
# File 'sig/client.rbs', line 116
def create_location_azure_blob: (
|
#create_location_efs(params = {}) ⇒ Types::CreateLocationEfsResponse
Creates a transfer location for an Amazon EFS file system. DataSync can use this location as a source or destination for transferring data.
Before you begin, make sure that you understand how DataSync accesses Amazon EFS file systems.
148 |
# File 'sig/client.rbs', line 148
def create_location_efs: (
|
#create_location_fsx_lustre(params = {}) ⇒ Types::CreateLocationFsxLustreResponse
Creates a transfer location for an Amazon FSx for Lustre file system. DataSync can use this location as a source or destination for transferring data.
Before you begin, make sure that you understand how DataSync accesses FSx for Lustre file systems.
172 |
# File 'sig/client.rbs', line 172
def create_location_fsx_lustre: (
|
#create_location_fsx_ontap(params = {}) ⇒ Types::CreateLocationFsxOntapResponse
Creates a transfer location for an Amazon FSx for NetApp ONTAP file system. DataSync can use this location as a source or destination for transferring data.
Before you begin, make sure that you understand how DataSync accesses FSx for ONTAP file systems.
190 |
# File 'sig/client.rbs', line 190
def create_location_fsx_ontap: (
|
#create_location_fsx_open_zfs(params = {}) ⇒ Types::CreateLocationFsxOpenZfsResponse
Creates a transfer location for an Amazon FSx for OpenZFS file system. DataSync can use this location as a source or destination for transferring data.
Before you begin, make sure that you understand how DataSync accesses FSx for OpenZFS file systems.
SMB aren't supported with the
CreateLocationFsxOpenZfs operation.
209 |
# File 'sig/client.rbs', line 209
def create_location_fsx_open_zfs: (
|
#create_location_fsx_windows(params = {}) ⇒ Types::CreateLocationFsxWindowsResponse
Creates a transfer location for an Amazon FSx for Windows File Server file system. DataSync can use this location as a source or destination for transferring data.
Before you begin, make sure that you understand how DataSync accesses FSx for Windows File Server file systems.
228 |
# File 'sig/client.rbs', line 228
def create_location_fsx_windows: (
|
#create_location_hdfs(params = {}) ⇒ Types::CreateLocationHdfsResponse
Creates a transfer location for a Hadoop Distributed File System (HDFS). DataSync can use this location as a source or destination for transferring data.
Before you begin, make sure that you understand how DataSync accesses HDFS clusters.
257 |
# File 'sig/client.rbs', line 257
def create_location_hdfs: (
|
#create_location_nfs(params = {}) ⇒ Types::CreateLocationNfsResponse
Creates a transfer location for a Network File System (NFS) file server. DataSync can use this location as a source or destination for transferring data.
Before you begin, make sure that you understand how DataSync accesses NFS file servers.
300 |
# File 'sig/client.rbs', line 300
def create_location_nfs: (
|
#create_location_object_storage(params = {}) ⇒ Types::CreateLocationObjectStorageResponse
Creates a transfer location for an object storage system. DataSync can use this location as a source or destination for transferring data. You can make transfers with or without a DataSync agent.
Before you begin, make sure that you understand the prerequisites for DataSync to work with object storage systems.
323 |
# File 'sig/client.rbs', line 323
def create_location_object_storage: (
|
#create_location_s3(params = {}) ⇒ Types::CreateLocationS3Response
Creates a transfer location for an Amazon S3 bucket. DataSync can use this location as a source or destination for transferring data.
Before you begin, make sure that you read the following topics:
For more information, see Configuring transfers with Amazon S3.
355 |
# File 'sig/client.rbs', line 355
def create_location_s3: (
|
#create_location_smb(params = {}) ⇒ Types::CreateLocationSmbResponse
Creates a transfer location for a Server Message Block (SMB) file server. DataSync can use this location as a source or destination for transferring data.
Before you begin, make sure that you understand how DataSync accesses SMB file servers. For more information, see Providing DataSync access to SMB file servers.
377 |
# File 'sig/client.rbs', line 377
def create_location_smb: (
|
#create_task(params = {}) ⇒ Types::CreateTaskResponse
Configures a task, which defines where and how DataSync transfers your data.
A task includes a source location, destination location, and transfer options (such as bandwidth limits, scheduling, and more).
If you're planning to transfer data to or from an Amazon S3 location, review how DataSync can affect your S3 request charges and the DataSync pricing page before you begin.
414 |
# File 'sig/client.rbs', line 414
def create_task: (
|
#delete_agent(params = {}) ⇒ Struct
Removes an DataSync agent resource from your Amazon Web Services account.
Keep in mind that this operation (which can't be undone) doesn't remove the agent's virtual machine (VM) or Amazon EC2 instance from your storage environment. For next steps, you can delete the VM or instance from your storage environment or reuse it to activate a new agent.
452 |
# File 'sig/client.rbs', line 452
def delete_agent: (
|
#delete_location(params = {}) ⇒ Struct
Deletes a transfer location resource from DataSync.
461 |
# File 'sig/client.rbs', line 461
def delete_location: (
|
#delete_task(params = {}) ⇒ Struct
Deletes a transfer task resource from DataSync.
470 |
# File 'sig/client.rbs', line 470
def delete_task: (
|
#describe_agent(params = {}) ⇒ Types::DescribeAgentResponse
Returns information about an DataSync agent, such as its name, service endpoint type, and status.
487 |
# File 'sig/client.rbs', line 487
def describe_agent: (
|
#describe_location_azure_blob(params = {}) ⇒ Types::DescribeLocationAzureBlobResponse
Provides details about how an DataSync transfer location for Microsoft Azure Blob Storage is configured.
506 |
# File 'sig/client.rbs', line 506
def describe_location_azure_blob: (
|
#describe_location_efs(params = {}) ⇒ Types::DescribeLocationEfsResponse
Provides details about how an DataSync transfer location for an Amazon EFS file system is configured.
522 |
# File 'sig/client.rbs', line 522
def describe_location_efs: (
|
#describe_location_fsx_lustre(params = {}) ⇒ Types::DescribeLocationFsxLustreResponse
Provides details about how an DataSync transfer location for an Amazon FSx for Lustre file system is configured.
535 |
# File 'sig/client.rbs', line 535
def describe_location_fsx_lustre: (
|
#describe_location_fsx_ontap(params = {}) ⇒ Types::DescribeLocationFsxOntapResponse
Provides details about how an DataSync transfer location for an Amazon FSx for NetApp ONTAP file system is configured.
DescribeLocationFsxOntap operation
doesn't actually return a Password.
551 |
# File 'sig/client.rbs', line 551
def describe_location_fsx_ontap: (
|
#describe_location_fsx_open_zfs(params = {}) ⇒ Types::DescribeLocationFsxOpenZfsResponse
Provides details about how an DataSync transfer location for an Amazon FSx for OpenZFS file system is configured.
SMB aren't supported with the
DescribeLocationFsxOpenZfs operation.
565 |
# File 'sig/client.rbs', line 565
def describe_location_fsx_open_zfs: (
|
#describe_location_fsx_windows(params = {}) ⇒ Types::DescribeLocationFsxWindowsResponse
Provides details about how an DataSync transfer location for an Amazon FSx for Windows File Server file system is configured.
583 |
# File 'sig/client.rbs', line 583
def describe_location_fsx_windows: (
|
#describe_location_hdfs(params = {}) ⇒ Types::DescribeLocationHdfsResponse
Provides details about how an DataSync transfer location for a Hadoop Distributed File System (HDFS) is configured.
607 |
# File 'sig/client.rbs', line 607
def describe_location_hdfs: (
|
#describe_location_nfs(params = {}) ⇒ Types::DescribeLocationNfsResponse
Provides details about how an DataSync transfer location for a Network File System (NFS) file server is configured.
621 |
# File 'sig/client.rbs', line 621
def describe_location_nfs: (
|
#describe_location_object_storage(params = {}) ⇒ Types::DescribeLocationObjectStorageResponse
Provides details about how an DataSync transfer location for an object storage system is configured.
641 |
# File 'sig/client.rbs', line 641
def describe_location_object_storage: (
|
#describe_location_s3(params = {}) ⇒ Types::DescribeLocationS3Response
Provides details about how an DataSync transfer location for an S3 bucket is configured.
656 |
# File 'sig/client.rbs', line 656
def describe_location_s3: (
|
#describe_location_smb(params = {}) ⇒ Types::DescribeLocationSmbResponse
Provides details about how an DataSync transfer location for a Server Message Block (SMB) file server is configured.
678 |
# File 'sig/client.rbs', line 678
def describe_location_smb: (
|
#describe_task(params = {}) ⇒ Types::DescribeTaskResponse
Provides information about a task, which defines where and how DataSync transfers your data.
707 |
# File 'sig/client.rbs', line 707
def describe_task: (
|
#describe_task_execution(params = {}) ⇒ Types::DescribeTaskExecutionResponse
Provides information about an execution of your DataSync task. You can use this operation to help monitor the progress of an ongoing data transfer or check the results of the transfer.
DescribeTaskExecution response elements are only relevant to a
specific task mode. For information, see Understanding task mode
differences and Understanding data transfer performance
counters.
751 |
# File 'sig/client.rbs', line 751
def describe_task_execution: (
|
#list_agents(params = {}) ⇒ Types::ListAgentsResponse
Returns a list of DataSync agents that belong to an Amazon Web Services account in the Amazon Web Services Region specified in the request.
With pagination, you can reduce the number of agents returned in a response. If you get a truncated list of agents in a response, the response contains a marker that you can specify in your next request to fetch the next page of agents.
ListAgents is eventually consistent. This means the result of
running the operation might not reflect that you just created or
deleted an agent. For example, if you create an agent with
CreateAgent and then immediately run ListAgents, that agent
might not show up in the list right away. In situations like this, you
can always confirm whether an agent has been created (or deleted) by
using DescribeAgent.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
762 |
# File 'sig/client.rbs', line 762
def list_agents: (
|
#list_locations(params = {}) ⇒ Types::ListLocationsResponse
Returns a list of source and destination locations.
If you have more locations than are returned in a response (that is, the response returns only a truncated list of your agents), the response contains a token that you can specify in your next request to fetch the next page of locations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
774 |
# File 'sig/client.rbs', line 774
def list_locations: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns all the tags associated with an Amazon Web Services resource.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
793 |
# File 'sig/client.rbs', line 793
def list_tags_for_resource: (
|
#list_task_executions(params = {}) ⇒ Types::ListTaskExecutionsResponse
Returns a list of executions for an DataSync transfer task.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
806 |
# File 'sig/client.rbs', line 806
def list_task_executions: (
|
#list_tasks(params = {}) ⇒ Types::ListTasksResponse
Returns a list of the DataSync tasks you created.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
819 |
# File 'sig/client.rbs', line 819
def list_tasks: (
|
#start_task_execution(params = {}) ⇒ Types::StartTaskExecutionResponse
Starts an DataSync transfer task. For each task, you can only run one task execution at a time.
There are several steps to a task execution. For more information, see Task execution statuses.
If you're planning to transfer data to or from an Amazon S3 location, review how DataSync can affect your S3 request charges and the DataSync pricing page before you begin.
837 |
# File 'sig/client.rbs', line 837
def start_task_execution: (
|
#tag_resource(params = {}) ⇒ Struct
Applies a tag to an Amazon Web Services resource. Tags are key-value pairs that can help you manage, filter, and search for your resources.
These include DataSync resources, such as locations, tasks, and task executions.
867 |
# File 'sig/client.rbs', line 867
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from an Amazon Web Services resource.
882 |
# File 'sig/client.rbs', line 882
def untag_resource: (
|
#update_agent(params = {}) ⇒ Struct
Updates the name of an DataSync agent.
892 |
# File 'sig/client.rbs', line 892
def update_agent: (
|
#update_location_azure_blob(params = {}) ⇒ Struct
Modifies the following configurations of the Microsoft Azure Blob Storage transfer location that you're using with DataSync.
For more information, see Configuring DataSync transfers with Azure Blob Storage.
902 |
# File 'sig/client.rbs', line 902
def update_location_azure_blob: (
|
#update_location_efs(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Amazon EFS transfer location that you're using with DataSync.
For more information, see Configuring DataSync transfers with Amazon EFS.
927 |
# File 'sig/client.rbs', line 927
def update_location_efs: (
|
#update_location_fsx_lustre(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Amazon FSx for Lustre transfer location that you're using with DataSync.
For more information, see Configuring DataSync transfers with FSx for Lustre.
940 |
# File 'sig/client.rbs', line 940
def update_location_fsx_lustre: (
|
#update_location_fsx_ontap(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Amazon FSx for NetApp ONTAP transfer location that you're using with DataSync.
For more information, see Configuring DataSync transfers with FSx for ONTAP.
950 |
# File 'sig/client.rbs', line 950
def update_location_fsx_ontap: (
|
#update_location_fsx_open_zfs(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Amazon FSx for OpenZFS transfer location that you're using with DataSync.
For more information, see Configuring DataSync transfers with FSx for OpenZFS.
SMB aren't supported with the
UpdateLocationFsxOpenZfs operation.
983 |
# File 'sig/client.rbs', line 983
def update_location_fsx_open_zfs: (
|
#update_location_fsx_windows(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Amazon FSx for Windows File Server transfer location that you're using with DataSync.
For more information, see Configuring DataSync transfers with FSx for Windows File Server.
994 |
# File 'sig/client.rbs', line 994
def update_location_fsx_windows: (
|
#update_location_hdfs(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Hadoop Distributed File System (HDFS) transfer location that you're using with DataSync.
For more information, see Configuring DataSync transfers with an HDFS cluster.
1015 |
# File 'sig/client.rbs', line 1015
def update_location_hdfs: (
|
#update_location_nfs(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Network File System (NFS) transfer location that you're using with DataSync.
For more information, see Configuring transfers with an NFS file server.
1052 |
# File 'sig/client.rbs', line 1052
def update_location_nfs: (
|
#update_location_object_storage(params = {}) ⇒ Struct
Modifies the following configuration parameters of the object storage transfer location that you're using with DataSync.
For more information, see Configuring DataSync transfers with an object storage system.
1069 |
# File 'sig/client.rbs', line 1069
def update_location_object_storage: (
|
#update_location_s3(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Amazon S3 transfer location that you're using with DataSync.
Before you begin, make sure that you read the following topics:
1094 |
# File 'sig/client.rbs', line 1094
def update_location_s3: (
|
#update_location_smb(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Server Message Block (SMB) transfer location that you're using with DataSync.
For more information, see Configuring DataSync transfers with an SMB file server.
1108 |
# File 'sig/client.rbs', line 1108
def update_location_smb: (
|
#update_task(params = {}) ⇒ Struct
Updates the configuration of a task, which defines where and how DataSync transfers your data.
1139 |
# File 'sig/client.rbs', line 1139
def update_task: (
|
#update_task_execution(params = {}) ⇒ Struct
Updates the configuration of a running DataSync task execution.
Option that you can modify with
UpdateTaskExecution is BytesPerSecond, which throttles bandwidth
for a running or queued task execution.
1169 |
# File 'sig/client.rbs', line 1169
def update_task_execution: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5161 5162 5163 |
# File 'lib/aws-sdk-datasync/client.rb', line 5161 def waiter_names [] end |