Class: Aws::DataSync::Types::CreateLocationAzureBlobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataSync::Types::CreateLocationAzureBlobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datasync/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_tier ⇒ String
Specifies the access tier that you want your objects or files transferred into.
-
#agent_arns ⇒ Array<String>
(Optional) Specifies the Amazon Resource Name (ARN) of the DataSync agent that can connect with your Azure Blob Storage container.
-
#authentication_type ⇒ String
Specifies the authentication method DataSync uses to access your Azure Blob Storage.
-
#blob_type ⇒ String
Specifies the type of blob that you want your objects or files to be when transferring them into Azure Blob Storage.
-
#cmk_secret_config ⇒ Types::CmkSecretConfig
Specifies configuration information for a DataSync-managed secret, which includes the authentication token that DataSync uses to access a specific AzureBlob storage location, with a customer-managed KMS key.
-
#container_url ⇒ String
Specifies the URL of the Azure Blob Storage container involved in your transfer.
-
#custom_secret_config ⇒ Types::CustomSecretConfig
Specifies configuration information for a customer-managed Secrets Manager secret where the authentication token for an AzureBlob storage location is stored in plain text, in Secrets Manager.
-
#sas_configuration ⇒ Types::AzureBlobSasConfiguration
Specifies the SAS configuration that allows DataSync to access your Azure Blob Storage.
-
#subdirectory ⇒ String
Specifies path segments if you want to limit your transfer to a virtual directory in your container (for example,
/my/images). -
#tags ⇒ Array<Types::TagListEntry>
Specifies labels that help you categorize, filter, and search for your Amazon Web Services resources.
Instance Attribute Details
#access_tier ⇒ String
Specifies the access tier that you want your objects or files transferred into. This only applies when using the location as a transfer destination. For more information, see [Access tiers].
345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/aws-sdk-datasync/types.rb', line 345 class CreateLocationAzureBlobRequest < Struct.new( :container_url, :authentication_type, :sas_configuration, :blob_type, :access_tier, :subdirectory, :agent_arns, :tags, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#agent_arns ⇒ Array<String>
(Optional) Specifies the Amazon Resource Name (ARN) of the DataSync agent that can connect with your Azure Blob Storage container. If you are setting up an agentless cross-cloud transfer, you do not need to specify a value for this parameter.
You can specify more than one agent. For more information, see [Using multiple agents for your transfer].
<note markdown=“1”> Make sure you configure this parameter correctly when you first create your storage location. You cannot add or remove agents from a storage location after you create it.
</note>
[1]: docs.aws.amazon.com/datasync/latest/userguide/multiple-agents.html
345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/aws-sdk-datasync/types.rb', line 345 class CreateLocationAzureBlobRequest < Struct.new( :container_url, :authentication_type, :sas_configuration, :blob_type, :access_tier, :subdirectory, :agent_arns, :tags, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#authentication_type ⇒ String
Specifies the authentication method DataSync uses to access your Azure Blob Storage. DataSync can access blob storage using a shared access signature (SAS).
345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/aws-sdk-datasync/types.rb', line 345 class CreateLocationAzureBlobRequest < Struct.new( :container_url, :authentication_type, :sas_configuration, :blob_type, :access_tier, :subdirectory, :agent_arns, :tags, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#blob_type ⇒ String
Specifies the type of blob that you want your objects or files to be when transferring them into Azure Blob Storage. Currently, DataSync only supports moving data into Azure Blob Storage as block blobs. For more information on blob types, see the [Azure Blob Storage documentation].
345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/aws-sdk-datasync/types.rb', line 345 class CreateLocationAzureBlobRequest < Struct.new( :container_url, :authentication_type, :sas_configuration, :blob_type, :access_tier, :subdirectory, :agent_arns, :tags, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#cmk_secret_config ⇒ Types::CmkSecretConfig
Specifies configuration information for a DataSync-managed secret, which includes the authentication token that DataSync uses to access a specific AzureBlob storage location, with a customer-managed KMS key.
When you include this parameter as part of a CreateLocationAzureBlob request, you provide only the KMS key ARN. DataSync uses this KMS key together with the authentication token you specify for SasConfiguration to create a DataSync-managed secret to store the location access credentials.
Make sure that DataSync has permission to access the KMS key that you specify. For more information, see [ Using a service-managed secret encrypted with a custom KMS key].
<note markdown=“1”> You can use either CmkSecretConfig (with SasConfiguration) or CustomSecretConfig (without SasConfiguration) to provide credentials for a CreateLocationAzureBlob request. Do not provide both parameters for the same request.
</note>
[1]: docs.aws.amazon.com/datasync/latest/userguide/location-credentials.html#service-secret-custom-key
345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/aws-sdk-datasync/types.rb', line 345 class CreateLocationAzureBlobRequest < Struct.new( :container_url, :authentication_type, :sas_configuration, :blob_type, :access_tier, :subdirectory, :agent_arns, :tags, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#container_url ⇒ String
Specifies the URL of the Azure Blob Storage container involved in your transfer.
345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/aws-sdk-datasync/types.rb', line 345 class CreateLocationAzureBlobRequest < Struct.new( :container_url, :authentication_type, :sas_configuration, :blob_type, :access_tier, :subdirectory, :agent_arns, :tags, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#custom_secret_config ⇒ Types::CustomSecretConfig
Specifies configuration information for a customer-managed Secrets Manager secret where the authentication token for an AzureBlob storage location is stored in plain text, in Secrets Manager. This configuration includes the secret ARN, and the ARN for an IAM role that provides access to the secret. For more information, see [ Using a secret that you manage].
<note markdown=“1”> You can use either CmkSecretConfig (with SasConfiguration) or CustomSecretConfig (without SasConfiguration) to provide credentials for a CreateLocationAzureBlob request. Do not provide both parameters for the same request.
</note>
[1]: docs.aws.amazon.com/datasync/latest/userguide/location-credentials.html#custom-secret-custom-key
345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/aws-sdk-datasync/types.rb', line 345 class CreateLocationAzureBlobRequest < Struct.new( :container_url, :authentication_type, :sas_configuration, :blob_type, :access_tier, :subdirectory, :agent_arns, :tags, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#sas_configuration ⇒ Types::AzureBlobSasConfiguration
Specifies the SAS configuration that allows DataSync to access your Azure Blob Storage.
<note markdown=“1”> If you provide an authentication token using SasConfiguration, but do not provide secret configuration details using CmkSecretConfig or CustomSecretConfig, then DataSync stores the token using your Amazon Web Services account’s secrets manager secret.
</note>
345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/aws-sdk-datasync/types.rb', line 345 class CreateLocationAzureBlobRequest < Struct.new( :container_url, :authentication_type, :sas_configuration, :blob_type, :access_tier, :subdirectory, :agent_arns, :tags, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#subdirectory ⇒ String
Specifies path segments if you want to limit your transfer to a virtual directory in your container (for example, /my/images).
345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/aws-sdk-datasync/types.rb', line 345 class CreateLocationAzureBlobRequest < Struct.new( :container_url, :authentication_type, :sas_configuration, :blob_type, :access_tier, :subdirectory, :agent_arns, :tags, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::TagListEntry>
Specifies labels that help you categorize, filter, and search for your Amazon Web Services resources. We recommend creating at least a name tag for your transfer location.
345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/aws-sdk-datasync/types.rb', line 345 class CreateLocationAzureBlobRequest < Struct.new( :container_url, :authentication_type, :sas_configuration, :blob_type, :access_tier, :subdirectory, :agent_arns, :tags, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |