Class: Aws::DataSync::Types::CreateLocationFsxOpenZfsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datasync/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fsx_filesystem_arnString

The Amazon Resource Name (ARN) of the FSx for OpenZFS file system.

Returns:

  • (String)


635
636
637
638
639
640
641
642
643
# File 'lib/aws-sdk-datasync/types.rb', line 635

class CreateLocationFsxOpenZfsRequest < Struct.new(
  :fsx_filesystem_arn,
  :protocol,
  :security_group_arns,
  :subdirectory,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#protocolTypes::FsxProtocol

The type of protocol that DataSync uses to access your file system.

Returns:



635
636
637
638
639
640
641
642
643
# File 'lib/aws-sdk-datasync/types.rb', line 635

class CreateLocationFsxOpenZfsRequest < Struct.new(
  :fsx_filesystem_arn,
  :protocol,
  :security_group_arns,
  :subdirectory,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_arnsArray<String>

The ARNs of the security groups that are used to configure the FSx for OpenZFS file system.

Returns:

  • (Array<String>)


635
636
637
638
639
640
641
642
643
# File 'lib/aws-sdk-datasync/types.rb', line 635

class CreateLocationFsxOpenZfsRequest < Struct.new(
  :fsx_filesystem_arn,
  :protocol,
  :security_group_arns,
  :subdirectory,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#subdirectoryString

A subdirectory in the location’s path that must begin with /fsx. DataSync uses this subdirectory to read or write data (depending on whether the file system is a source or destination location).

Returns:

  • (String)


635
636
637
638
639
640
641
642
643
# File 'lib/aws-sdk-datasync/types.rb', line 635

class CreateLocationFsxOpenZfsRequest < Struct.new(
  :fsx_filesystem_arn,
  :protocol,
  :security_group_arns,
  :subdirectory,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::TagListEntry>

The key-value pair that represents a tag that you want to add to the resource. The value can be an empty string. This value helps you manage, filter, and search for your resources. We recommend that you create a name tag for your location.

Returns:



635
636
637
638
639
640
641
642
643
# File 'lib/aws-sdk-datasync/types.rb', line 635

class CreateLocationFsxOpenZfsRequest < Struct.new(
  :fsx_filesystem_arn,
  :protocol,
  :security_group_arns,
  :subdirectory,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end