Class: Aws::DataSync::Types::CreateLocationFsxWindowsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataSync::Types::CreateLocationFsxWindowsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datasync/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:password]
Instance Attribute Summary collapse
-
#cmk_secret_config ⇒ Types::CmkSecretConfig
Specifies configuration information for a DataSync-managed secret, which includes the password that DataSync uses to access a specific FSx Windows storage location, with a customer-managed KMS key.
-
#custom_secret_config ⇒ Types::CustomSecretConfig
Specifies configuration information for a customer-managed Secrets Manager secret where the password for an FSx for Windows File Server storage location is stored in plain text, in Secrets Manager.
-
#domain ⇒ String
Specifies the name of the Windows domain that the FSx for Windows File Server file system belongs to.
-
#fsx_filesystem_arn ⇒ String
Specifies the Amazon Resource Name (ARN) for the FSx for Windows File Server file system.
-
#password ⇒ String
Specifies the password of the user with the permissions to mount and access the files, folders, and file metadata in your FSx for Windows File Server file system.
-
#security_group_arns ⇒ Array<String>
Specifies the ARNs of the Amazon EC2 security groups that provide access to your file system’s preferred subnet.
-
#subdirectory ⇒ String
Specifies a mount path for your file system using forward slashes.
-
#tags ⇒ Array<Types::TagListEntry>
Specifies labels that help you categorize, filter, and search for your Amazon Web Services resources.
-
#user ⇒ String
Specifies the user with the permissions to mount and access the files, folders, and file metadata in your FSx for Windows File Server file system.
Instance Attribute Details
#cmk_secret_config ⇒ Types::CmkSecretConfig
Specifies configuration information for a DataSync-managed secret, which includes the password that DataSync uses to access a specific FSx Windows storage location, with a customer-managed KMS key.
When you include this parameter as part of a CreateLocationFsxWindows request, you provide only the KMS key ARN. DataSync uses this KMS key together with the Password you specify for to create a DataSync-managed secret to store the location access credentials.
Make sure that DataSync has permission to access the KMS key that you specify. For more information, see [ Using a service-managed secret encrypted with a custom KMS key].
<note markdown=“1”> You can use either CmkSecretConfig (with Password) or CustomSecretConfig (without Password) to provide credentials for a CreateLocationFsxWindows request. Do not provide both parameters for the same request.
</note>
[1]: docs.aws.amazon.com/datasync/latest/userguide/location-credentials.html#service-secret-custom-key
778 779 780 781 782 783 784 785 786 787 788 789 790 |
# File 'lib/aws-sdk-datasync/types.rb', line 778 class CreateLocationFsxWindowsRequest < Struct.new( :subdirectory, :fsx_filesystem_arn, :security_group_arns, :tags, :user, :domain, :password, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:password] include Aws::Structure end |
#custom_secret_config ⇒ Types::CustomSecretConfig
Specifies configuration information for a customer-managed Secrets Manager secret where the password for an FSx for Windows File Server storage location is stored in plain text, in Secrets Manager. This configuration includes the secret ARN, and the ARN for an IAM role that provides access to the secret. For more information, see [ Using a secret that you manage].
<note markdown=“1”> You can use either CmkSecretConfig (with Password) or CustomSecretConfig (without Password) to provide credentials for a CreateLocationFsxWindows request. Do not provide both parameters for the same request.
</note>
[1]: docs.aws.amazon.com/datasync/latest/userguide/location-credentials.html#custom-secret-custom-key
778 779 780 781 782 783 784 785 786 787 788 789 790 |
# File 'lib/aws-sdk-datasync/types.rb', line 778 class CreateLocationFsxWindowsRequest < Struct.new( :subdirectory, :fsx_filesystem_arn, :security_group_arns, :tags, :user, :domain, :password, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:password] include Aws::Structure end |
#domain ⇒ String
Specifies the name of the Windows domain that the FSx for Windows File Server file system belongs to.
If you have multiple Active Directory domains in your environment, configuring this parameter makes sure that DataSync connects to the right file system.
778 779 780 781 782 783 784 785 786 787 788 789 790 |
# File 'lib/aws-sdk-datasync/types.rb', line 778 class CreateLocationFsxWindowsRequest < Struct.new( :subdirectory, :fsx_filesystem_arn, :security_group_arns, :tags, :user, :domain, :password, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:password] include Aws::Structure end |
#fsx_filesystem_arn ⇒ String
Specifies the Amazon Resource Name (ARN) for the FSx for Windows File Server file system.
778 779 780 781 782 783 784 785 786 787 788 789 790 |
# File 'lib/aws-sdk-datasync/types.rb', line 778 class CreateLocationFsxWindowsRequest < Struct.new( :subdirectory, :fsx_filesystem_arn, :security_group_arns, :tags, :user, :domain, :password, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:password] include Aws::Structure end |
#password ⇒ String
Specifies the password of the user with the permissions to mount and access the files, folders, and file metadata in your FSx for Windows File Server file system.
778 779 780 781 782 783 784 785 786 787 788 789 790 |
# File 'lib/aws-sdk-datasync/types.rb', line 778 class CreateLocationFsxWindowsRequest < Struct.new( :subdirectory, :fsx_filesystem_arn, :security_group_arns, :tags, :user, :domain, :password, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:password] include Aws::Structure end |
#security_group_arns ⇒ Array<String>
Specifies the ARNs of the Amazon EC2 security groups that provide access to your file system’s preferred subnet.
The security groups that you specify must be able to communicate with your file system’s security groups. For information about configuring security groups for file system access, see the [ *Amazon FSx for Windows File Server User Guide* ][1].
<note markdown=“1”> If you choose a security group that doesn’t allow connections from within itself, do one of the following:
* Configure the security group to allow it to communicate within
itself.
-
Choose a different security group that can communicate with the mount target’s security group.
</note>
[1]: docs.aws.amazon.com/fsx/latest/WindowsGuide/limit-access-security-groups.html
778 779 780 781 782 783 784 785 786 787 788 789 790 |
# File 'lib/aws-sdk-datasync/types.rb', line 778 class CreateLocationFsxWindowsRequest < Struct.new( :subdirectory, :fsx_filesystem_arn, :security_group_arns, :tags, :user, :domain, :password, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:password] include Aws::Structure end |
#subdirectory ⇒ String
Specifies a mount path for your file system using forward slashes. This is where DataSync reads or writes data (depending on if this is a source or destination location).
778 779 780 781 782 783 784 785 786 787 788 789 790 |
# File 'lib/aws-sdk-datasync/types.rb', line 778 class CreateLocationFsxWindowsRequest < Struct.new( :subdirectory, :fsx_filesystem_arn, :security_group_arns, :tags, :user, :domain, :password, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:password] include Aws::Structure end |
#tags ⇒ Array<Types::TagListEntry>
Specifies labels that help you categorize, filter, and search for your Amazon Web Services resources. We recommend creating at least a name tag for your location.
778 779 780 781 782 783 784 785 786 787 788 789 790 |
# File 'lib/aws-sdk-datasync/types.rb', line 778 class CreateLocationFsxWindowsRequest < Struct.new( :subdirectory, :fsx_filesystem_arn, :security_group_arns, :tags, :user, :domain, :password, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:password] include Aws::Structure end |
#user ⇒ String
Specifies the user with the permissions to mount and access the files, folders, and file metadata in your FSx for Windows File Server file system.
For information about choosing a user with the right level of access for your transfer, see [required permissions] for FSx for Windows File Server locations.
778 779 780 781 782 783 784 785 786 787 788 789 790 |
# File 'lib/aws-sdk-datasync/types.rb', line 778 class CreateLocationFsxWindowsRequest < Struct.new( :subdirectory, :fsx_filesystem_arn, :security_group_arns, :tags, :user, :domain, :password, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:password] include Aws::Structure end |