Class: Aws::DataSync::Types::CreateLocationHdfsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datasync/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_arnsArray<String>

The Amazon Resource Names (ARNs) of the DataSync agents that can connect to your HDFS cluster.

Returns:

  • (Array<String>)


951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
# File 'lib/aws-sdk-datasync/types.rb', line 951

class CreateLocationHdfsRequest < Struct.new(
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :tags,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#authentication_typeString

The type of authentication used to determine the identity of the user.

Returns:

  • (String)


951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
# File 'lib/aws-sdk-datasync/types.rb', line 951

class CreateLocationHdfsRequest < Struct.new(
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :tags,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#block_sizeInteger

The size of data blocks to write into the HDFS cluster. The block size must be a multiple of 512 bytes. The default block size is 128 mebibytes (MiB).

Returns:

  • (Integer)


951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
# File 'lib/aws-sdk-datasync/types.rb', line 951

class CreateLocationHdfsRequest < Struct.new(
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :tags,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#cmk_secret_configTypes::CmkSecretConfig

Specifies configuration information for a DataSync-managed secret, which includes the Kerberos keytab that DataSync uses to access a specific Hadoop Distributed File System (HDFS) storage location, with a customer-managed KMS key.

When you include this parameter as part of a CreateLocationHdfs request, you provide only the KMS key ARN. DataSync uses this KMS key together with the KerberosKeytab you specify for to create a DataSync-managed secret to store the location access credentials.

Make sure that DataSync has permission to access the KMS key that you specify. For more information, see [ Using a service-managed secret encrypted with a custom KMS key].

<note markdown=“1”> You can use either CmkSecretConfig (with KerberosKeytab) or CustomSecretConfig (without KerberosKeytab) to provide credentials for a CreateLocationHdfs request. Do not provide both parameters for the same request.

</note>

[1]: docs.aws.amazon.com/datasync/latest/userguide/location-credentials.html#service-secret-custom-key



951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
# File 'lib/aws-sdk-datasync/types.rb', line 951

class CreateLocationHdfsRequest < Struct.new(
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :tags,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#custom_secret_configTypes::CustomSecretConfig

Specifies configuration information for a customer-managed Secrets Manager secret where the Kerberos keytab for the HDFS storage location is stored in binary, in Secrets Manager. This configuration includes the secret ARN, and the ARN for an IAM role that provides access to the secret. For more information, see [ Using a secret that you manage].

<note markdown=“1”> You can use either CmkSecretConfig (with KerberosKeytab) or CustomSecretConfig (without KerberosKeytab) to provide credentials for a CreateLocationHdfs request. Do not provide both parameters for the same request.

</note>

[1]: docs.aws.amazon.com/datasync/latest/userguide/location-credentials.html#custom-secret-custom-key



951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
# File 'lib/aws-sdk-datasync/types.rb', line 951

class CreateLocationHdfsRequest < Struct.new(
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :tags,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#kerberos_keytabString

The Kerberos key table (keytab) that contains mappings between the defined Kerberos principal and the encrypted keys. You can load the keytab from a file by providing the file’s address.

<note markdown=“1”> If KERBEROS is specified for AuthenticationType, this parameter is required.

</note>

Returns:

  • (String)


951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
# File 'lib/aws-sdk-datasync/types.rb', line 951

class CreateLocationHdfsRequest < Struct.new(
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :tags,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#kerberos_krb_5_confString

The krb5.conf file that contains the Kerberos configuration information. You can load the krb5.conf file by providing the file’s address. If you’re using the CLI, it performs the base64 encoding for you. Otherwise, provide the base64-encoded text.

<note markdown=“1”> If KERBEROS is specified for AuthenticationType, this parameter is required.

</note>

Returns:

  • (String)


951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
# File 'lib/aws-sdk-datasync/types.rb', line 951

class CreateLocationHdfsRequest < Struct.new(
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :tags,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#kerberos_principalString

The Kerberos principal with access to the files and folders on the HDFS cluster.

<note markdown=“1”> If KERBEROS is specified for AuthenticationType, this parameter is required.

</note>

Returns:

  • (String)


951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
# File 'lib/aws-sdk-datasync/types.rb', line 951

class CreateLocationHdfsRequest < Struct.new(
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :tags,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_provider_uriString

The URI of the HDFS cluster’s Key Management Server (KMS).

Returns:

  • (String)


951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
# File 'lib/aws-sdk-datasync/types.rb', line 951

class CreateLocationHdfsRequest < Struct.new(
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :tags,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#name_nodesArray<Types::HdfsNameNode>

The NameNode that manages the HDFS namespace. The NameNode performs operations such as opening, closing, and renaming files and directories. The NameNode contains the information to map blocks of data to the DataNodes. You can use only one NameNode.

Returns:



951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
# File 'lib/aws-sdk-datasync/types.rb', line 951

class CreateLocationHdfsRequest < Struct.new(
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :tags,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#qop_configurationTypes::QopConfiguration

The Quality of Protection (QOP) configuration specifies the Remote Procedure Call (RPC) and data transfer protection settings configured on the Hadoop Distributed File System (HDFS) cluster. If QopConfiguration isn’t specified, RpcProtection and DataTransferProtection default to PRIVACY. If you set RpcProtection or DataTransferProtection, the other parameter assumes the same value.



951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
# File 'lib/aws-sdk-datasync/types.rb', line 951

class CreateLocationHdfsRequest < Struct.new(
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :tags,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#replication_factorInteger

The number of DataNodes to replicate the data to when writing to the HDFS cluster. By default, data is replicated to three DataNodes.

Returns:

  • (Integer)


951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
# File 'lib/aws-sdk-datasync/types.rb', line 951

class CreateLocationHdfsRequest < Struct.new(
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :tags,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#simple_userString

The user name used to identify the client on the host operating system.

<note markdown=“1”> If SIMPLE is specified for AuthenticationType, this parameter is required.

</note>

Returns:

  • (String)


951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
# File 'lib/aws-sdk-datasync/types.rb', line 951

class CreateLocationHdfsRequest < Struct.new(
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :tags,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#subdirectoryString

A subdirectory in the HDFS cluster. This subdirectory is used to read data from or write data to the HDFS cluster. If the subdirectory isn’t specified, it will default to /.

Returns:

  • (String)


951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
# File 'lib/aws-sdk-datasync/types.rb', line 951

class CreateLocationHdfsRequest < Struct.new(
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :tags,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::TagListEntry>

The key-value pair that represents the tag that you want to add to the location. The value can be an empty string. We recommend using tags to name your resources.

Returns:



951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
# File 'lib/aws-sdk-datasync/types.rb', line 951

class CreateLocationHdfsRequest < Struct.new(
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :tags,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end