Class: Aws::DataSync::Types::CreateLocationObjectStorageRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datasync/types.rb

Overview

CreateLocationObjectStorageRequest

Constant Summary collapse

SENSITIVE =
[:secret_key]

Instance Attribute Summary collapse

Instance Attribute Details

#access_keyString

Specifies the access key (for example, a user name) if credentials are required to authenticate with the object storage server.

Returns:

  • (String)


1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
# File 'lib/aws-sdk-datasync/types.rb', line 1194

class CreateLocationObjectStorageRequest < Struct.new(
  :server_hostname,
  :server_port,
  :server_protocol,
  :subdirectory,
  :bucket_name,
  :access_key,
  :secret_key,
  :agent_arns,
  :tags,
  :server_certificate,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = [:secret_key]
  include Aws::Structure
end

#agent_arnsArray<String>

(Optional) Specifies the Amazon Resource Names (ARNs) of the DataSync agents that can connect with your object storage system. If you are setting up an agentless cross-cloud transfer, you do not need to specify a value for this parameter.

<note markdown=“1”> Make sure you configure this parameter correctly when you first create your storage location. You cannot add or remove agents from a storage location after you create it.

</note>

Returns:

  • (Array<String>)


1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
# File 'lib/aws-sdk-datasync/types.rb', line 1194

class CreateLocationObjectStorageRequest < Struct.new(
  :server_hostname,
  :server_port,
  :server_protocol,
  :subdirectory,
  :bucket_name,
  :access_key,
  :secret_key,
  :agent_arns,
  :tags,
  :server_certificate,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = [:secret_key]
  include Aws::Structure
end

#bucket_nameString

Specifies the name of the object storage bucket involved in the transfer.

Returns:

  • (String)


1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
# File 'lib/aws-sdk-datasync/types.rb', line 1194

class CreateLocationObjectStorageRequest < Struct.new(
  :server_hostname,
  :server_port,
  :server_protocol,
  :subdirectory,
  :bucket_name,
  :access_key,
  :secret_key,
  :agent_arns,
  :tags,
  :server_certificate,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = [:secret_key]
  include Aws::Structure
end

#cmk_secret_configTypes::CmkSecretConfig

Specifies configuration information for a DataSync-managed secret, which includes the SecretKey that DataSync uses to access a specific object storage location, with a customer-managed KMS key.

When you include this parameter as part of a CreateLocationObjectStorage request, you provide only the KMS key ARN. DataSync uses this KMS key together with the value you specify for the SecretKey parameter to create a DataSync-managed secret to store the location access credentials.

Make sure that DataSync has permission to access the KMS key that you specify. For more information, see [ Using a service-managed secret encrypted with a custom KMS key].

<note markdown=“1”> You can use either CmkSecretConfig (with SecretKey) or CustomSecretConfig (without SecretKey) to provide credentials for a CreateLocationObjectStorage request. Do not provide both parameters for the same request.

</note>

[1]: docs.aws.amazon.com/datasync/latest/userguide/location-credentials.html#service-secret-custom-key



1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
# File 'lib/aws-sdk-datasync/types.rb', line 1194

class CreateLocationObjectStorageRequest < Struct.new(
  :server_hostname,
  :server_port,
  :server_protocol,
  :subdirectory,
  :bucket_name,
  :access_key,
  :secret_key,
  :agent_arns,
  :tags,
  :server_certificate,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = [:secret_key]
  include Aws::Structure
end

#custom_secret_configTypes::CustomSecretConfig

Specifies configuration information for a customer-managed Secrets Manager secret where the secret key for a specific object storage location is stored in plain text, in Secrets Manager. This configuration includes the secret ARN, and the ARN for an IAM role that provides access to the secret. For more information, see [ Using a secret that you manage].

<note markdown=“1”> You can use either CmkSecretConfig (with SecretKey) or CustomSecretConfig (without SecretKey) to provide credentials for a CreateLocationObjectStorage request. Do not provide both parameters for the same request.

</note>

[1]: docs.aws.amazon.com/datasync/latest/userguide/location-credentials.html#custom-secret-custom-key



1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
# File 'lib/aws-sdk-datasync/types.rb', line 1194

class CreateLocationObjectStorageRequest < Struct.new(
  :server_hostname,
  :server_port,
  :server_protocol,
  :subdirectory,
  :bucket_name,
  :access_key,
  :secret_key,
  :agent_arns,
  :tags,
  :server_certificate,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = [:secret_key]
  include Aws::Structure
end

#secret_keyString

Specifies the secret key (for example, a password) if credentials are required to authenticate with the object storage server.

<note markdown=“1”> If you provide a secret using SecretKey, but do not provide secret configuration details using CmkSecretConfig or CustomSecretConfig, then DataSync stores the token using your Amazon Web Services account’s Secrets Manager secret.

</note>

Returns:

  • (String)


1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
# File 'lib/aws-sdk-datasync/types.rb', line 1194

class CreateLocationObjectStorageRequest < Struct.new(
  :server_hostname,
  :server_port,
  :server_protocol,
  :subdirectory,
  :bucket_name,
  :access_key,
  :secret_key,
  :agent_arns,
  :tags,
  :server_certificate,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = [:secret_key]
  include Aws::Structure
end

#server_certificateString

Specifies a certificate chain for DataSync to authenticate with your object storage system if the system uses a private or self-signed certificate authority (CA). You must specify a single .pem file with a full certificate chain (for example, file:///home/user/.ssh/object_storage_certificates.pem).

The certificate chain might include:

  • The object storage system’s certificate

  • All intermediate certificates (if there are any)

  • The root certificate of the signing CA

You can concatenate your certificates into a .pem file (which can be up to 32768 bytes before base64 encoding). The following example cat command creates an object_storage_certificates.pem file that includes three certificates:

‘cat object_server_certificate.pem intermediate_certificate.pem ca_root_certificate.pem > object_storage_certificates.pem`

To use this parameter, configure ServerProtocol to HTTPS.

Returns:

  • (String)


1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
# File 'lib/aws-sdk-datasync/types.rb', line 1194

class CreateLocationObjectStorageRequest < Struct.new(
  :server_hostname,
  :server_port,
  :server_protocol,
  :subdirectory,
  :bucket_name,
  :access_key,
  :secret_key,
  :agent_arns,
  :tags,
  :server_certificate,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = [:secret_key]
  include Aws::Structure
end

#server_hostnameString

Specifies the domain name or IP address (IPv4 or IPv6) of the object storage server that your DataSync agent connects to.

Returns:

  • (String)


1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
# File 'lib/aws-sdk-datasync/types.rb', line 1194

class CreateLocationObjectStorageRequest < Struct.new(
  :server_hostname,
  :server_port,
  :server_protocol,
  :subdirectory,
  :bucket_name,
  :access_key,
  :secret_key,
  :agent_arns,
  :tags,
  :server_certificate,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = [:secret_key]
  include Aws::Structure
end

#server_portInteger

Specifies the port that your object storage server accepts inbound network traffic on (for example, port 443).

Returns:

  • (Integer)


1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
# File 'lib/aws-sdk-datasync/types.rb', line 1194

class CreateLocationObjectStorageRequest < Struct.new(
  :server_hostname,
  :server_port,
  :server_protocol,
  :subdirectory,
  :bucket_name,
  :access_key,
  :secret_key,
  :agent_arns,
  :tags,
  :server_certificate,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = [:secret_key]
  include Aws::Structure
end

#server_protocolString

Specifies the protocol that your object storage server uses to communicate. If not specified, the default value is HTTPS.

Returns:

  • (String)


1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
# File 'lib/aws-sdk-datasync/types.rb', line 1194

class CreateLocationObjectStorageRequest < Struct.new(
  :server_hostname,
  :server_port,
  :server_protocol,
  :subdirectory,
  :bucket_name,
  :access_key,
  :secret_key,
  :agent_arns,
  :tags,
  :server_certificate,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = [:secret_key]
  include Aws::Structure
end

#subdirectoryString

Specifies the object prefix for your object storage server. If this is a source location, DataSync only copies objects with this prefix. If this is a destination location, DataSync writes all objects with this prefix.

Returns:

  • (String)


1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
# File 'lib/aws-sdk-datasync/types.rb', line 1194

class CreateLocationObjectStorageRequest < Struct.new(
  :server_hostname,
  :server_port,
  :server_protocol,
  :subdirectory,
  :bucket_name,
  :access_key,
  :secret_key,
  :agent_arns,
  :tags,
  :server_certificate,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = [:secret_key]
  include Aws::Structure
end

#tagsArray<Types::TagListEntry>

Specifies the key-value pair that represents a tag that you want to add to the resource. Tags can help you manage, filter, and search for your resources. We recommend creating a name tag for your location.

Returns:



1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
# File 'lib/aws-sdk-datasync/types.rb', line 1194

class CreateLocationObjectStorageRequest < Struct.new(
  :server_hostname,
  :server_port,
  :server_protocol,
  :subdirectory,
  :bucket_name,
  :access_key,
  :secret_key,
  :agent_arns,
  :tags,
  :server_certificate,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = [:secret_key]
  include Aws::Structure
end