Class: Aws::DataSync::Types::CustomSecretConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datasync/types.rb

Overview

Specifies configuration information for a customer-managed Secrets Manager secret where a storage location credentials is stored in Secrets Manager as plain text (for authentication token, secret key, or password) or as binary (for Kerberos keytab). This configuration includes the secret ARN, and the ARN for an IAM role that provides access to the secret.

<note markdown=“1”> You can use either CmkSecretConfig or CustomSecretConfig to provide credentials for a CreateLocation request. Do not provide both parameters for the same request.

</note>

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#secret_access_role_arnString

Specifies the ARN for the Identity and Access Management role that DataSync uses to access the secret specified for SecretArn.

Returns:

  • (String)


1742
1743
1744
1745
1746
1747
# File 'lib/aws-sdk-datasync/types.rb', line 1742

class CustomSecretConfig < Struct.new(
  :secret_arn,
  :secret_access_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#secret_arnString

Specifies the ARN for an Secrets Manager secret.

Returns:

  • (String)


1742
1743
1744
1745
1746
1747
# File 'lib/aws-sdk-datasync/types.rb', line 1742

class CustomSecretConfig < Struct.new(
  :secret_arn,
  :secret_access_role_arn)
  SENSITIVE = []
  include Aws::Structure
end