Class: Aws::DataSync::Types::DescribeLocationAzureBlobResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datasync/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_tierString

The access tier that you want your objects or files transferred into. This only applies when using the location as a transfer destination. For more information, see [Access tiers].

[1]: docs.aws.amazon.com/datasync/latest/userguide/creating-azure-blob-location.html#azure-blob-access-tiers

Returns:

  • (String)


1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
# File 'lib/aws-sdk-datasync/types.rb', line 1978

class DescribeLocationAzureBlobResponse < Struct.new(
  :location_arn,
  :location_uri,
  :authentication_type,
  :blob_type,
  :access_tier,
  :agent_arns,
  :creation_time,
  :managed_secret_config,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#agent_arnsArray<String>

The ARNs of the DataSync agents that can connect with your Azure Blob Storage container.

Returns:

  • (Array<String>)


1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
# File 'lib/aws-sdk-datasync/types.rb', line 1978

class DescribeLocationAzureBlobResponse < Struct.new(
  :location_arn,
  :location_uri,
  :authentication_type,
  :blob_type,
  :access_tier,
  :agent_arns,
  :creation_time,
  :managed_secret_config,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#authentication_typeString

The authentication method DataSync uses to access your Azure Blob Storage. DataSync can access blob storage using a shared access signature (SAS).

Returns:

  • (String)


1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
# File 'lib/aws-sdk-datasync/types.rb', line 1978

class DescribeLocationAzureBlobResponse < Struct.new(
  :location_arn,
  :location_uri,
  :authentication_type,
  :blob_type,
  :access_tier,
  :agent_arns,
  :creation_time,
  :managed_secret_config,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#blob_typeString

The type of blob that you want your objects or files to be when transferring them into Azure Blob Storage. Currently, DataSync only supports moving data into Azure Blob Storage as block blobs. For more information on blob types, see the [Azure Blob Storage documentation].

[1]: learn.microsoft.com/en-us/rest/api/storageservices/understanding-block-blobs–append-blobs–and-page-blobs

Returns:

  • (String)


1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
# File 'lib/aws-sdk-datasync/types.rb', line 1978

class DescribeLocationAzureBlobResponse < Struct.new(
  :location_arn,
  :location_uri,
  :authentication_type,
  :blob_type,
  :access_tier,
  :agent_arns,
  :creation_time,
  :managed_secret_config,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#cmk_secret_configTypes::CmkSecretConfig

Describes configuration information for a DataSync-managed secret, such as an authentication token that DataSync uses to access a specific storage location, with a customer-managed KMS key.



1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
# File 'lib/aws-sdk-datasync/types.rb', line 1978

class DescribeLocationAzureBlobResponse < Struct.new(
  :location_arn,
  :location_uri,
  :authentication_type,
  :blob_type,
  :access_tier,
  :agent_arns,
  :creation_time,
  :managed_secret_config,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The time that your Azure Blob Storage transfer location was created.

Returns:

  • (Time)


1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
# File 'lib/aws-sdk-datasync/types.rb', line 1978

class DescribeLocationAzureBlobResponse < Struct.new(
  :location_arn,
  :location_uri,
  :authentication_type,
  :blob_type,
  :access_tier,
  :agent_arns,
  :creation_time,
  :managed_secret_config,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#custom_secret_configTypes::CustomSecretConfig

Describes configuration information for a customer-managed secret, such as an authentication token that DataSync uses to access a specific storage location, with a customer-managed Identity and Access Management (IAM) role that provides access to the secret.



1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
# File 'lib/aws-sdk-datasync/types.rb', line 1978

class DescribeLocationAzureBlobResponse < Struct.new(
  :location_arn,
  :location_uri,
  :authentication_type,
  :blob_type,
  :access_tier,
  :agent_arns,
  :creation_time,
  :managed_secret_config,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#location_arnString

The ARN of your Azure Blob Storage transfer location.

Returns:

  • (String)


1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
# File 'lib/aws-sdk-datasync/types.rb', line 1978

class DescribeLocationAzureBlobResponse < Struct.new(
  :location_arn,
  :location_uri,
  :authentication_type,
  :blob_type,
  :access_tier,
  :agent_arns,
  :creation_time,
  :managed_secret_config,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#location_uriString

The URL of the Azure Blob Storage container involved in your transfer.

Returns:

  • (String)


1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
# File 'lib/aws-sdk-datasync/types.rb', line 1978

class DescribeLocationAzureBlobResponse < Struct.new(
  :location_arn,
  :location_uri,
  :authentication_type,
  :blob_type,
  :access_tier,
  :agent_arns,
  :creation_time,
  :managed_secret_config,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#managed_secret_configTypes::ManagedSecretConfig

Describes configuration information for a DataSync-managed secret, such as an authentication token that DataSync uses to access a specific storage location. DataSync uses the default Amazon Web Services-managed KMS key to encrypt this secret in Secrets Manager.



1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
# File 'lib/aws-sdk-datasync/types.rb', line 1978

class DescribeLocationAzureBlobResponse < Struct.new(
  :location_arn,
  :location_uri,
  :authentication_type,
  :blob_type,
  :access_tier,
  :agent_arns,
  :creation_time,
  :managed_secret_config,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end