Class: Aws::DataSync::Types::DescribeLocationEfsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataSync::Types::DescribeLocationEfsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datasync/types.rb
Overview
DescribeLocationEfsResponse
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_point_arn ⇒ String
The ARN of the access point that DataSync uses to access the Amazon EFS file system.
-
#creation_time ⇒ Time
The time that the location was created.
-
#ec2_config ⇒ Types::Ec2Config
The subnet and security groups that DataSync uses to connect to one of your Amazon EFS file system’s [mount targets].
-
#file_system_access_role_arn ⇒ String
The Identity and Access Management (IAM) role that allows DataSync to access your Amazon EFS file system.
-
#in_transit_encryption ⇒ String
Indicates whether DataSync uses Transport Layer Security (TLS) encryption when transferring data to or from the Amazon EFS file system.
-
#location_arn ⇒ String
The ARN of the Amazon EFS file system location.
-
#location_uri ⇒ String
The URL of the Amazon EFS file system location.
Instance Attribute Details
#access_point_arn ⇒ String
The ARN of the access point that DataSync uses to access the Amazon EFS file system.
For more information, see [Accessing restricted file systems].
[1]: docs.aws.amazon.com/datasync/latest/userguide/create-efs-location.html#create-efs-location-iam
2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 |
# File 'lib/aws-sdk-datasync/types.rb', line 2062 class DescribeLocationEfsResponse < Struct.new( :location_arn, :location_uri, :ec2_config, :creation_time, :access_point_arn, :file_system_access_role_arn, :in_transit_encryption) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time that the location was created.
2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 |
# File 'lib/aws-sdk-datasync/types.rb', line 2062 class DescribeLocationEfsResponse < Struct.new( :location_arn, :location_uri, :ec2_config, :creation_time, :access_point_arn, :file_system_access_role_arn, :in_transit_encryption) SENSITIVE = [] include Aws::Structure end |
#ec2_config ⇒ Types::Ec2Config
The subnet and security groups that DataSync uses to connect to one of your Amazon EFS file system’s [mount targets].
2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 |
# File 'lib/aws-sdk-datasync/types.rb', line 2062 class DescribeLocationEfsResponse < Struct.new( :location_arn, :location_uri, :ec2_config, :creation_time, :access_point_arn, :file_system_access_role_arn, :in_transit_encryption) SENSITIVE = [] include Aws::Structure end |
#file_system_access_role_arn ⇒ String
The Identity and Access Management (IAM) role that allows DataSync to access your Amazon EFS file system.
For more information, see [Creating a DataSync IAM role for file system access].
[1]: docs.aws.amazon.com/datasync/latest/userguide/create-efs-location.html#create-efs-location-iam-role
2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 |
# File 'lib/aws-sdk-datasync/types.rb', line 2062 class DescribeLocationEfsResponse < Struct.new( :location_arn, :location_uri, :ec2_config, :creation_time, :access_point_arn, :file_system_access_role_arn, :in_transit_encryption) SENSITIVE = [] include Aws::Structure end |
#in_transit_encryption ⇒ String
Indicates whether DataSync uses Transport Layer Security (TLS) encryption when transferring data to or from the Amazon EFS file system.
2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 |
# File 'lib/aws-sdk-datasync/types.rb', line 2062 class DescribeLocationEfsResponse < Struct.new( :location_arn, :location_uri, :ec2_config, :creation_time, :access_point_arn, :file_system_access_role_arn, :in_transit_encryption) SENSITIVE = [] include Aws::Structure end |
#location_arn ⇒ String
The ARN of the Amazon EFS file system location.
2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 |
# File 'lib/aws-sdk-datasync/types.rb', line 2062 class DescribeLocationEfsResponse < Struct.new( :location_arn, :location_uri, :ec2_config, :creation_time, :access_point_arn, :file_system_access_role_arn, :in_transit_encryption) SENSITIVE = [] include Aws::Structure end |
#location_uri ⇒ String
The URL of the Amazon EFS file system location.
2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 |
# File 'lib/aws-sdk-datasync/types.rb', line 2062 class DescribeLocationEfsResponse < Struct.new( :location_arn, :location_uri, :ec2_config, :creation_time, :access_point_arn, :file_system_access_role_arn, :in_transit_encryption) SENSITIVE = [] include Aws::Structure end |