Class: Aws::DataSync::Types::DescribeLocationHdfsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataSync::Types::DescribeLocationHdfsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datasync/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_arns ⇒ Array<String>
The ARNs of the DataSync agents that can connect with your HDFS cluster.
-
#authentication_type ⇒ String
The type of authentication used to determine the identity of the user.
-
#block_size ⇒ Integer
The size of the data blocks to write into the HDFS cluster.
-
#cmk_secret_config ⇒ Types::CmkSecretConfig
Describes configuration information for a DataSync-managed secret, such as a
KerberosKeytabthat DataSync uses to access a specific storage location, with a customer-managed KMS key. -
#creation_time ⇒ Time
The time that the HDFS location was created.
-
#custom_secret_config ⇒ Types::CustomSecretConfig
Describes configuration information for a customer-managed secret, such as a
KerberosKeytabthat DataSync uses to access a specific storage location, with a customer-managed Identity and Access Management (IAM) role that provides access to the secret. -
#kerberos_principal ⇒ String
The Kerberos principal with access to the files and folders on the HDFS cluster.
-
#kms_key_provider_uri ⇒ String
The URI of the HDFS cluster’s Key Management Server (KMS).
-
#location_arn ⇒ String
The ARN of the HDFS location.
-
#location_uri ⇒ String
The URI of the HDFS location.
-
#managed_secret_config ⇒ Types::ManagedSecretConfig
Describes configuration information for a DataSync-managed secret, such as a
KerberosKeytabthat DataSync uses to access a specific storage location. -
#name_nodes ⇒ Array<Types::HdfsNameNode>
The NameNode that manages the HDFS namespace.
-
#qop_configuration ⇒ Types::QopConfiguration
The Quality of Protection (QOP) configuration, which specifies the Remote Procedure Call (RPC) and data transfer protection settings configured on the HDFS cluster.
-
#replication_factor ⇒ Integer
The number of DataNodes to replicate the data to when writing to the HDFS cluster.
-
#simple_user ⇒ String
The user name to identify the client on the host operating system.
Instance Attribute Details
#agent_arns ⇒ Array<String>
The ARNs of the DataSync agents that can connect with your HDFS cluster.
2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 |
# File 'lib/aws-sdk-datasync/types.rb', line 2400 class DescribeLocationHdfsResponse < Struct.new( :location_arn, :location_uri, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :agent_arns, :creation_time, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#authentication_type ⇒ String
The type of authentication used to determine the identity of the user.
2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 |
# File 'lib/aws-sdk-datasync/types.rb', line 2400 class DescribeLocationHdfsResponse < Struct.new( :location_arn, :location_uri, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :agent_arns, :creation_time, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#block_size ⇒ Integer
The size of the data blocks to write into the HDFS cluster.
2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 |
# File 'lib/aws-sdk-datasync/types.rb', line 2400 class DescribeLocationHdfsResponse < Struct.new( :location_arn, :location_uri, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :agent_arns, :creation_time, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#cmk_secret_config ⇒ Types::CmkSecretConfig
Describes configuration information for a DataSync-managed secret, such as a KerberosKeytab that DataSync uses to access a specific storage location, with a customer-managed KMS key.
2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 |
# File 'lib/aws-sdk-datasync/types.rb', line 2400 class DescribeLocationHdfsResponse < Struct.new( :location_arn, :location_uri, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :agent_arns, :creation_time, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time that the HDFS location was created.
2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 |
# File 'lib/aws-sdk-datasync/types.rb', line 2400 class DescribeLocationHdfsResponse < Struct.new( :location_arn, :location_uri, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :agent_arns, :creation_time, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#custom_secret_config ⇒ Types::CustomSecretConfig
Describes configuration information for a customer-managed secret, such as a KerberosKeytab that DataSync uses to access a specific storage location, with a customer-managed Identity and Access Management (IAM) role that provides access to the secret.
2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 |
# File 'lib/aws-sdk-datasync/types.rb', line 2400 class DescribeLocationHdfsResponse < Struct.new( :location_arn, :location_uri, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :agent_arns, :creation_time, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#kerberos_principal ⇒ String
The Kerberos principal with access to the files and folders on the HDFS cluster. This parameter is used if the AuthenticationType is defined as KERBEROS.
2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 |
# File 'lib/aws-sdk-datasync/types.rb', line 2400 class DescribeLocationHdfsResponse < Struct.new( :location_arn, :location_uri, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :agent_arns, :creation_time, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#kms_key_provider_uri ⇒ String
The URI of the HDFS cluster’s Key Management Server (KMS).
2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 |
# File 'lib/aws-sdk-datasync/types.rb', line 2400 class DescribeLocationHdfsResponse < Struct.new( :location_arn, :location_uri, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :agent_arns, :creation_time, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#location_arn ⇒ String
The ARN of the HDFS location.
2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 |
# File 'lib/aws-sdk-datasync/types.rb', line 2400 class DescribeLocationHdfsResponse < Struct.new( :location_arn, :location_uri, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :agent_arns, :creation_time, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#location_uri ⇒ String
The URI of the HDFS location.
2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 |
# File 'lib/aws-sdk-datasync/types.rb', line 2400 class DescribeLocationHdfsResponse < Struct.new( :location_arn, :location_uri, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :agent_arns, :creation_time, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#managed_secret_config ⇒ Types::ManagedSecretConfig
Describes configuration information for a DataSync-managed secret, such as a KerberosKeytab that DataSync uses to access a specific storage location. DataSync uses the default Amazon Web Services-managed KMS key to encrypt this secret in Secrets Manager.
2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 |
# File 'lib/aws-sdk-datasync/types.rb', line 2400 class DescribeLocationHdfsResponse < Struct.new( :location_arn, :location_uri, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :agent_arns, :creation_time, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#name_nodes ⇒ Array<Types::HdfsNameNode>
The NameNode that manages the HDFS namespace.
2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 |
# File 'lib/aws-sdk-datasync/types.rb', line 2400 class DescribeLocationHdfsResponse < Struct.new( :location_arn, :location_uri, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :agent_arns, :creation_time, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#qop_configuration ⇒ Types::QopConfiguration
The Quality of Protection (QOP) configuration, which specifies the Remote Procedure Call (RPC) and data transfer protection settings configured on the HDFS cluster.
2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 |
# File 'lib/aws-sdk-datasync/types.rb', line 2400 class DescribeLocationHdfsResponse < Struct.new( :location_arn, :location_uri, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :agent_arns, :creation_time, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#replication_factor ⇒ Integer
The number of DataNodes to replicate the data to when writing to the HDFS cluster.
2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 |
# File 'lib/aws-sdk-datasync/types.rb', line 2400 class DescribeLocationHdfsResponse < Struct.new( :location_arn, :location_uri, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :agent_arns, :creation_time, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#simple_user ⇒ String
The user name to identify the client on the host operating system. This parameter is used if the AuthenticationType is defined as SIMPLE.
2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 |
# File 'lib/aws-sdk-datasync/types.rb', line 2400 class DescribeLocationHdfsResponse < Struct.new( :location_arn, :location_uri, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :agent_arns, :creation_time, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |