Class: Aws::DataSync::Types::DescribeLocationObjectStorageResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataSync::Types::DescribeLocationObjectStorageResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datasync/types.rb
Overview
DescribeLocationObjectStorageResponse
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_key ⇒ String
The access key (for example, a user name) required to authenticate with the object storage system.
-
#agent_arns ⇒ Array<String>
The ARNs of the DataSync agents that can connect with your object storage system.
-
#cmk_secret_config ⇒ Types::CmkSecretConfig
Describes configuration information for a DataSync-managed secret, such as an authentication token or set of credentials that DataSync uses to access a specific transfer location, and a customer-managed KMS key.
-
#creation_time ⇒ Time
The time that the location was created.
-
#custom_secret_config ⇒ Types::CustomSecretConfig
Describes configuration information for a customer-managed secret, such as an authentication token or set of credentials that DataSync uses to access a specific transfer location, and a customer-managed Identity and Access Management (IAM) role that provides access to the secret.
-
#location_arn ⇒ String
The ARN of the object storage system location.
-
#location_uri ⇒ String
The URI of the object storage system location.
-
#managed_secret_config ⇒ Types::ManagedSecretConfig
Describes configuration information for a DataSync-managed secret, such as an authentication token or set of credentials that DataSync uses to access a specific transfer location.
-
#server_certificate ⇒ String
The certificate chain for DataSync to authenticate with your object storage system if the system uses a private or self-signed certificate authority (CA).
-
#server_port ⇒ Integer
The port that your object storage server accepts inbound network traffic on (for example, port 443).
-
#server_protocol ⇒ String
The protocol that your object storage system uses to communicate.
Instance Attribute Details
#access_key ⇒ String
The access key (for example, a user name) required to authenticate with the object storage system.
2549 2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 |
# File 'lib/aws-sdk-datasync/types.rb', line 2549 class DescribeLocationObjectStorageResponse < Struct.new( :location_arn, :location_uri, :access_key, :server_port, :server_protocol, :agent_arns, :creation_time, :server_certificate, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#agent_arns ⇒ Array<String>
The ARNs of the DataSync agents that can connect with your object storage system.
2549 2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 |
# File 'lib/aws-sdk-datasync/types.rb', line 2549 class DescribeLocationObjectStorageResponse < Struct.new( :location_arn, :location_uri, :access_key, :server_port, :server_protocol, :agent_arns, :creation_time, :server_certificate, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#cmk_secret_config ⇒ Types::CmkSecretConfig
Describes configuration information for a DataSync-managed secret, such as an authentication token or set of credentials that DataSync uses to access a specific transfer location, and a customer-managed KMS key.
2549 2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 |
# File 'lib/aws-sdk-datasync/types.rb', line 2549 class DescribeLocationObjectStorageResponse < Struct.new( :location_arn, :location_uri, :access_key, :server_port, :server_protocol, :agent_arns, :creation_time, :server_certificate, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time that the location was created.
2549 2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 |
# File 'lib/aws-sdk-datasync/types.rb', line 2549 class DescribeLocationObjectStorageResponse < Struct.new( :location_arn, :location_uri, :access_key, :server_port, :server_protocol, :agent_arns, :creation_time, :server_certificate, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#custom_secret_config ⇒ Types::CustomSecretConfig
Describes configuration information for a customer-managed secret, such as an authentication token or set of credentials that DataSync uses to access a specific transfer location, and a customer-managed Identity and Access Management (IAM) role that provides access to the secret.
2549 2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 |
# File 'lib/aws-sdk-datasync/types.rb', line 2549 class DescribeLocationObjectStorageResponse < Struct.new( :location_arn, :location_uri, :access_key, :server_port, :server_protocol, :agent_arns, :creation_time, :server_certificate, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#location_arn ⇒ String
The ARN of the object storage system location.
2549 2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 |
# File 'lib/aws-sdk-datasync/types.rb', line 2549 class DescribeLocationObjectStorageResponse < Struct.new( :location_arn, :location_uri, :access_key, :server_port, :server_protocol, :agent_arns, :creation_time, :server_certificate, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#location_uri ⇒ String
The URI of the object storage system location.
2549 2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 |
# File 'lib/aws-sdk-datasync/types.rb', line 2549 class DescribeLocationObjectStorageResponse < Struct.new( :location_arn, :location_uri, :access_key, :server_port, :server_protocol, :agent_arns, :creation_time, :server_certificate, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#managed_secret_config ⇒ Types::ManagedSecretConfig
Describes configuration information for a DataSync-managed secret, such as an authentication token or set of credentials that DataSync uses to access a specific transfer location. DataSync uses the default Amazon Web Services-managed KMS key to encrypt this secret in Secrets Manager.
2549 2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 |
# File 'lib/aws-sdk-datasync/types.rb', line 2549 class DescribeLocationObjectStorageResponse < Struct.new( :location_arn, :location_uri, :access_key, :server_port, :server_protocol, :agent_arns, :creation_time, :server_certificate, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#server_certificate ⇒ String
The certificate chain for DataSync to authenticate with your object storage system if the system uses a private or self-signed certificate authority (CA).
2549 2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 |
# File 'lib/aws-sdk-datasync/types.rb', line 2549 class DescribeLocationObjectStorageResponse < Struct.new( :location_arn, :location_uri, :access_key, :server_port, :server_protocol, :agent_arns, :creation_time, :server_certificate, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#server_port ⇒ Integer
The port that your object storage server accepts inbound network traffic on (for example, port 443).
2549 2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 |
# File 'lib/aws-sdk-datasync/types.rb', line 2549 class DescribeLocationObjectStorageResponse < Struct.new( :location_arn, :location_uri, :access_key, :server_port, :server_protocol, :agent_arns, :creation_time, :server_certificate, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#server_protocol ⇒ String
The protocol that your object storage system uses to communicate.
2549 2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 |
# File 'lib/aws-sdk-datasync/types.rb', line 2549 class DescribeLocationObjectStorageResponse < Struct.new( :location_arn, :location_uri, :access_key, :server_port, :server_protocol, :agent_arns, :creation_time, :server_certificate, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |