Class: Aws::DataSync::Types::DescribeStorageSystemResourcesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataSync::Types::DescribeStorageSystemResourcesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datasync/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#discovery_job_arn ⇒ String
Specifies the Amazon Resource Name (ARN) of the discovery job that’s collecting data from your on-premises storage system.
-
#filter ⇒ Hash<String,Array<String>>
Filters the storage system resources that you want returned.
-
#max_results ⇒ Integer
Specifies the maximum number of storage system resources that you want to list in a response.
-
#next_token ⇒ String
Specifies an opaque string that indicates the position to begin the next list of results in the response.
-
#resource_ids ⇒ Array<String>
Specifies the universally unique identifiers (UUIDs) of the storage system resources that you want information about.
-
#resource_type ⇒ String
Specifies what kind of storage system resources that you want information about.
Instance Attribute Details
#discovery_job_arn ⇒ String
Specifies the Amazon Resource Name (ARN) of the discovery job that’s collecting data from your on-premises storage system.
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 |
# File 'lib/aws-sdk-datasync/types.rb', line 2503 class DescribeStorageSystemResourcesRequest < Struct.new( :discovery_job_arn, :resource_type, :resource_ids, :filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#filter ⇒ Hash<String,Array<String>>
Filters the storage system resources that you want returned. For example, this might be volumes associated with a specific storage virtual machine (SVM).
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 |
# File 'lib/aws-sdk-datasync/types.rb', line 2503 class DescribeStorageSystemResourcesRequest < Struct.new( :discovery_job_arn, :resource_type, :resource_ids, :filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Specifies the maximum number of storage system resources that you want to list in a response.
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 |
# File 'lib/aws-sdk-datasync/types.rb', line 2503 class DescribeStorageSystemResourcesRequest < Struct.new( :discovery_job_arn, :resource_type, :resource_ids, :filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Specifies an opaque string that indicates the position to begin the next list of results in the response.
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 |
# File 'lib/aws-sdk-datasync/types.rb', line 2503 class DescribeStorageSystemResourcesRequest < Struct.new( :discovery_job_arn, :resource_type, :resource_ids, :filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#resource_ids ⇒ Array<String>
Specifies the universally unique identifiers (UUIDs) of the storage system resources that you want information about. You can’t use this parameter in combination with the Filter parameter.
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 |
# File 'lib/aws-sdk-datasync/types.rb', line 2503 class DescribeStorageSystemResourcesRequest < Struct.new( :discovery_job_arn, :resource_type, :resource_ids, :filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
Specifies what kind of storage system resources that you want information about.
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 |
# File 'lib/aws-sdk-datasync/types.rb', line 2503 class DescribeStorageSystemResourcesRequest < Struct.new( :discovery_job_arn, :resource_type, :resource_ids, :filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |