Class: Aws::DataSync::Types::FsxUpdateProtocolSmb

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datasync/types.rb

Overview

Specifies the Server Message Block (SMB) protocol configuration that DataSync uses to access your Amazon FSx for NetApp ONTAP file system’s storage virtual machine (SVM). For more information, see [Providing DataSync access to FSx for ONTAP file systems].

[1]: docs.aws.amazon.com/datasync/latest/userguide/create-ontap-location.html#create-ontap-location-access

Constant Summary collapse

SENSITIVE =
[:password]

Instance Attribute Summary collapse

Instance Attribute Details

#cmk_secret_configTypes::CmkSecretConfig

Specifies configuration information for a DataSync-managed secret, such as a Password or set of credentials that DataSync uses to access a specific transfer location, and a customer-managed KMS key.



3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
# File 'lib/aws-sdk-datasync/types.rb', line 3799

class FsxUpdateProtocolSmb < Struct.new(
  :domain,
  :mount_options,
  :password,
  :user,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = [:password]
  include Aws::Structure
end

#custom_secret_configTypes::CustomSecretConfig

Specifies configuration information for a customer-managed secret, such as a Password or set of credentials that DataSync uses to access a specific transfer location. This configuration includes the secret ARN, and the ARN for an IAM role that provides access to the secret.



3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
# File 'lib/aws-sdk-datasync/types.rb', line 3799

class FsxUpdateProtocolSmb < Struct.new(
  :domain,
  :mount_options,
  :password,
  :user,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = [:password]
  include Aws::Structure
end

#domainString

Specifies the name of the Windows domain that your storage virtual machine (SVM) belongs to.

If you have multiple Active Directory domains in your environment, configuring this parameter makes sure that DataSync connects to the right SVM.

Returns:

  • (String)


3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
# File 'lib/aws-sdk-datasync/types.rb', line 3799

class FsxUpdateProtocolSmb < Struct.new(
  :domain,
  :mount_options,
  :password,
  :user,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = [:password]
  include Aws::Structure
end

#mount_optionsTypes::SmbMountOptions

Specifies the version of the Server Message Block (SMB) protocol that DataSync uses to access an SMB file server.



3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
# File 'lib/aws-sdk-datasync/types.rb', line 3799

class FsxUpdateProtocolSmb < Struct.new(
  :domain,
  :mount_options,
  :password,
  :user,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = [:password]
  include Aws::Structure
end

#passwordString

Specifies the password of a user who has permission to access your SVM.

Returns:

  • (String)


3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
# File 'lib/aws-sdk-datasync/types.rb', line 3799

class FsxUpdateProtocolSmb < Struct.new(
  :domain,
  :mount_options,
  :password,
  :user,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = [:password]
  include Aws::Structure
end

#userString

Specifies a user that can mount and access the files, folders, and metadata in your SVM.

For information about choosing a user with the right level of access for your transfer, see [Using the SMB protocol].

[1]: docs.aws.amazon.com/datasync/latest/userguide/create-ontap-location.html#create-ontap-location-smb

Returns:

  • (String)


3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
# File 'lib/aws-sdk-datasync/types.rb', line 3799

class FsxUpdateProtocolSmb < Struct.new(
  :domain,
  :mount_options,
  :password,
  :user,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = [:password]
  include Aws::Structure
end