Class: Aws::DataSync::Types::ListTaskExecutionsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datasync/types.rb

Overview

ListTaskExecutionsResponse

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The opaque string that indicates the position to begin the next list of results in the response.

Returns:

  • (String)


4050
4051
4052
4053
4054
4055
# File 'lib/aws-sdk-datasync/types.rb', line 4050

class ListTaskExecutionsResponse < Struct.new(
  :task_executions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#task_executionsArray<Types::TaskExecutionListEntry>

A list of the task’s executions.

Returns:



4050
4051
4052
4053
4054
4055
# File 'lib/aws-sdk-datasync/types.rb', line 4050

class ListTaskExecutionsResponse < Struct.new(
  :task_executions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end