Class: Aws::DataSync::Types::ListTasksRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datasync/types.rb

Overview

ListTasksRequest

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersArray<Types::TaskFilter>

You can use API filters to narrow down the list of resources returned by ListTasks. For example, to retrieve all tasks on a specific source location, you can use ListTasks with filter name LocationId and ‘Operator Equals` with the ARN for the location.

Returns:



4077
4078
4079
4080
4081
4082
4083
# File 'lib/aws-sdk-datasync/types.rb', line 4077

class ListTasksRequest < Struct.new(
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of tasks to return.

Returns:

  • (Integer)


4077
4078
4079
4080
4081
4082
4083
# File 'lib/aws-sdk-datasync/types.rb', line 4077

class ListTasksRequest < Struct.new(
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

An opaque string that indicates the position at which to begin the next list of tasks.

Returns:

  • (String)


4077
4078
4079
4080
4081
4082
4083
# File 'lib/aws-sdk-datasync/types.rb', line 4077

class ListTasksRequest < Struct.new(
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end