Class: Aws::DataSync::Types::ReportOverrides

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datasync/types.rb

Overview

The level of detail included in each aspect of your DataSync [task report].

[1]: docs.aws.amazon.com/datasync/latest/userguide/task-reports.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deletedTypes::ReportOverride

Specifies the level of reporting for the files, objects, and directories that DataSync attempted to delete in your destination location. This only applies if you [configure your task] to delete data in the destination that isn’t in the source.

[1]: docs.aws.amazon.com/datasync/latest/userguide/configure-metadata.html



4876
4877
4878
4879
4880
4881
4882
4883
# File 'lib/aws-sdk-datasync/types.rb', line 4876

class ReportOverrides < Struct.new(
  :transferred,
  :verified,
  :deleted,
  :skipped)
  SENSITIVE = []
  include Aws::Structure
end

#skippedTypes::ReportOverride

Specifies the level of reporting for the files, objects, and directories that DataSync attempted to skip during your transfer.



4876
4877
4878
4879
4880
4881
4882
4883
# File 'lib/aws-sdk-datasync/types.rb', line 4876

class ReportOverrides < Struct.new(
  :transferred,
  :verified,
  :deleted,
  :skipped)
  SENSITIVE = []
  include Aws::Structure
end

#transferredTypes::ReportOverride

Specifies the level of reporting for the files, objects, and directories that DataSync attempted to transfer.



4876
4877
4878
4879
4880
4881
4882
4883
# File 'lib/aws-sdk-datasync/types.rb', line 4876

class ReportOverrides < Struct.new(
  :transferred,
  :verified,
  :deleted,
  :skipped)
  SENSITIVE = []
  include Aws::Structure
end

#verifiedTypes::ReportOverride

Specifies the level of reporting for the files, objects, and directories that DataSync attempted to verify at the end of your transfer.



4876
4877
4878
4879
4880
4881
4882
4883
# File 'lib/aws-sdk-datasync/types.rb', line 4876

class ReportOverrides < Struct.new(
  :transferred,
  :verified,
  :deleted,
  :skipped)
  SENSITIVE = []
  include Aws::Structure
end