Class: Aws::DataSync::Types::ReportResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataSync::Types::ReportResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datasync/types.rb
Overview
Indicates whether DataSync created a complete task report for your transfer.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_code ⇒ String
Indicates the code associated with the error if DataSync can't create a complete report.
-
#error_detail ⇒ String
Provides details about issues creating a report.
-
#status ⇒ String
Indicates whether DataSync is still working on your report, created a report, or can't create a complete report.
Instance Attribute Details
#error_code ⇒ String
Indicates the code associated with the error if DataSync can't create a complete report.
4924 4925 4926 4927 4928 4929 4930 |
# File 'lib/aws-sdk-datasync/types.rb', line 4924 class ReportResult < Struct.new( :status, :error_code, :error_detail) SENSITIVE = [] include Aws::Structure end |
#error_detail ⇒ String
Provides details about issues creating a report.
4924 4925 4926 4927 4928 4929 4930 |
# File 'lib/aws-sdk-datasync/types.rb', line 4924 class ReportResult < Struct.new( :status, :error_code, :error_detail) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Indicates whether DataSync is still working on your report, created a report, or can't create a complete report.
4924 4925 4926 4927 4928 4929 4930 |
# File 'lib/aws-sdk-datasync/types.rb', line 4924 class ReportResult < Struct.new( :status, :error_code, :error_detail) SENSITIVE = [] include Aws::Structure end |