Class: Aws::DataSync::Types::UpdateLocationAzureBlobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datasync/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_tierString

Specifies the access tier that you want your objects or files transferred into. This only applies when using the location as a transfer destination. For more information, see [Access tiers].

[1]: docs.aws.amazon.com/datasync/latest/userguide/creating-azure-blob-location.html#azure-blob-access-tiers

Returns:

  • (String)


5938
5939
5940
5941
5942
5943
5944
5945
5946
5947
5948
5949
5950
# File 'lib/aws-sdk-datasync/types.rb', line 5938

class UpdateLocationAzureBlobRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :authentication_type,
  :sas_configuration,
  :blob_type,
  :access_tier,
  :agent_arns,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#agent_arnsArray<String>

(Optional) Specifies the Amazon Resource Name (ARN) of the DataSync agent that can connect with your Azure Blob Storage container. If you are setting up an agentless cross-cloud transfer, you do not need to specify a value for this parameter.

You can specify more than one agent. For more information, see [Using multiple agents for your transfer].

<note markdown=“1”> You cannot add or remove agents from a storage location after you initially create it.

</note>

[1]: docs.aws.amazon.com/datasync/latest/userguide/multiple-agents.html

Returns:

  • (Array<String>)


5938
5939
5940
5941
5942
5943
5944
5945
5946
5947
5948
5949
5950
# File 'lib/aws-sdk-datasync/types.rb', line 5938

class UpdateLocationAzureBlobRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :authentication_type,
  :sas_configuration,
  :blob_type,
  :access_tier,
  :agent_arns,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#authentication_typeString

Specifies the authentication method DataSync uses to access your Azure Blob Storage. DataSync can access blob storage using a shared access signature (SAS).

Returns:

  • (String)


5938
5939
5940
5941
5942
5943
5944
5945
5946
5947
5948
5949
5950
# File 'lib/aws-sdk-datasync/types.rb', line 5938

class UpdateLocationAzureBlobRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :authentication_type,
  :sas_configuration,
  :blob_type,
  :access_tier,
  :agent_arns,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#blob_typeString

Specifies the type of blob that you want your objects or files to be when transferring them into Azure Blob Storage. Currently, DataSync only supports moving data into Azure Blob Storage as block blobs. For more information on blob types, see the [Azure Blob Storage documentation].

[1]: learn.microsoft.com/en-us/rest/api/storageservices/understanding-block-blobs–append-blobs–and-page-blobs

Returns:

  • (String)


5938
5939
5940
5941
5942
5943
5944
5945
5946
5947
5948
5949
5950
# File 'lib/aws-sdk-datasync/types.rb', line 5938

class UpdateLocationAzureBlobRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :authentication_type,
  :sas_configuration,
  :blob_type,
  :access_tier,
  :agent_arns,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#cmk_secret_configTypes::CmkSecretConfig

Specifies configuration information for a DataSync-managed secret, such as an authentication token or set of credentials that DataSync uses to access a specific transfer location, and a customer-managed KMS key.



5938
5939
5940
5941
5942
5943
5944
5945
5946
5947
5948
5949
5950
# File 'lib/aws-sdk-datasync/types.rb', line 5938

class UpdateLocationAzureBlobRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :authentication_type,
  :sas_configuration,
  :blob_type,
  :access_tier,
  :agent_arns,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#custom_secret_configTypes::CustomSecretConfig

Specifies configuration information for a customer-managed secret, such as an authentication token or set of credentials that DataSync uses to access a specific transfer location, and a customer-managed Identity and Access Management (IAM) role that provides access to the secret.



5938
5939
5940
5941
5942
5943
5944
5945
5946
5947
5948
5949
5950
# File 'lib/aws-sdk-datasync/types.rb', line 5938

class UpdateLocationAzureBlobRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :authentication_type,
  :sas_configuration,
  :blob_type,
  :access_tier,
  :agent_arns,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#location_arnString

Specifies the ARN of the Azure Blob Storage transfer location that you’re updating.

Returns:

  • (String)


5938
5939
5940
5941
5942
5943
5944
5945
5946
5947
5948
5949
5950
# File 'lib/aws-sdk-datasync/types.rb', line 5938

class UpdateLocationAzureBlobRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :authentication_type,
  :sas_configuration,
  :blob_type,
  :access_tier,
  :agent_arns,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#sas_configurationTypes::AzureBlobSasConfiguration

Specifies the SAS configuration that allows DataSync to access your Azure Blob Storage.



5938
5939
5940
5941
5942
5943
5944
5945
5946
5947
5948
5949
5950
# File 'lib/aws-sdk-datasync/types.rb', line 5938

class UpdateLocationAzureBlobRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :authentication_type,
  :sas_configuration,
  :blob_type,
  :access_tier,
  :agent_arns,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#subdirectoryString

Specifies path segments if you want to limit your transfer to a virtual directory in your container (for example, /my/images).

Returns:

  • (String)


5938
5939
5940
5941
5942
5943
5944
5945
5946
5947
5948
5949
5950
# File 'lib/aws-sdk-datasync/types.rb', line 5938

class UpdateLocationAzureBlobRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :authentication_type,
  :sas_configuration,
  :blob_type,
  :access_tier,
  :agent_arns,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end