Class: Aws::DataSync::Types::UpdateLocationFsxOpenZfsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datasync/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#location_arnString

Specifies the Amazon Resource Name (ARN) of the FSx for OpenZFS transfer location that you’re updating.

Returns:

  • (String)


6117
6118
6119
6120
6121
6122
6123
# File 'lib/aws-sdk-datasync/types.rb', line 6117

class UpdateLocationFsxOpenZfsRequest < Struct.new(
  :location_arn,
  :protocol,
  :subdirectory)
  SENSITIVE = []
  include Aws::Structure
end

#protocolTypes::FsxProtocol

Specifies the data transfer protocol that DataSync uses to access your Amazon FSx file system.

Returns:



6117
6118
6119
6120
6121
6122
6123
# File 'lib/aws-sdk-datasync/types.rb', line 6117

class UpdateLocationFsxOpenZfsRequest < Struct.new(
  :location_arn,
  :protocol,
  :subdirectory)
  SENSITIVE = []
  include Aws::Structure
end

#subdirectoryString

Specifies a subdirectory in the location’s path that must begin with /fsx. DataSync uses this subdirectory to read or write data (depending on whether the file system is a source or destination location).

Returns:

  • (String)


6117
6118
6119
6120
6121
6122
6123
# File 'lib/aws-sdk-datasync/types.rb', line 6117

class UpdateLocationFsxOpenZfsRequest < Struct.new(
  :location_arn,
  :protocol,
  :subdirectory)
  SENSITIVE = []
  include Aws::Structure
end