Class: Aws::DataSync::Types::UpdateLocationFsxWindowsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datasync/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:password]

Instance Attribute Summary collapse

Instance Attribute Details

#cmk_secret_configTypes::CmkSecretConfig

Specifies configuration information for a DataSync-managed secret, such as a Password or set of credentials that DataSync uses to access a specific transfer location, and a customer-managed KMS key.



6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
6194
# File 'lib/aws-sdk-datasync/types.rb', line 6184

class UpdateLocationFsxWindowsRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :domain,
  :user,
  :password,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = [:password]
  include Aws::Structure
end

#custom_secret_configTypes::CustomSecretConfig

Specifies configuration information for a customer-managed secret, such as a Password or set of credentials that DataSync uses to access a specific transfer location, and a customer-managed Identity and Access Management (IAM) role that provides access to the secret.



6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
6194
# File 'lib/aws-sdk-datasync/types.rb', line 6184

class UpdateLocationFsxWindowsRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :domain,
  :user,
  :password,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = [:password]
  include Aws::Structure
end

#domainString

Specifies the name of the Windows domain that your FSx for Windows File Server file system belongs to.

If you have multiple Active Directory domains in your environment, configuring this parameter makes sure that DataSync connects to the right file system.

Returns:

  • (String)


6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
6194
# File 'lib/aws-sdk-datasync/types.rb', line 6184

class UpdateLocationFsxWindowsRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :domain,
  :user,
  :password,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = [:password]
  include Aws::Structure
end

#location_arnString

Specifies the ARN of the FSx for Windows File Server transfer location that you’re updating.

Returns:

  • (String)


6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
6194
# File 'lib/aws-sdk-datasync/types.rb', line 6184

class UpdateLocationFsxWindowsRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :domain,
  :user,
  :password,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = [:password]
  include Aws::Structure
end

#passwordString

Specifies the password of the user with the permissions to mount and access the files, folders, and file metadata in your FSx for Windows File Server file system.

Returns:

  • (String)


6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
6194
# File 'lib/aws-sdk-datasync/types.rb', line 6184

class UpdateLocationFsxWindowsRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :domain,
  :user,
  :password,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = [:password]
  include Aws::Structure
end

#subdirectoryString

Specifies a mount path for your file system using forward slashes. DataSync uses this subdirectory to read or write data (depending on whether the file system is a source or destination location).

Returns:

  • (String)


6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
6194
# File 'lib/aws-sdk-datasync/types.rb', line 6184

class UpdateLocationFsxWindowsRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :domain,
  :user,
  :password,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = [:password]
  include Aws::Structure
end

#userString

Specifies the user with the permissions to mount and access the files, folders, and file metadata in your FSx for Windows File Server file system.

For information about choosing a user with the right level of access for your transfer, see [required permissions] for FSx for Windows File Server locations.

[1]: docs.aws.amazon.com/datasync/latest/userguide/create-fsx-location.html#create-fsx-windows-location-permissions

Returns:

  • (String)


6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
6194
# File 'lib/aws-sdk-datasync/types.rb', line 6184

class UpdateLocationFsxWindowsRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :domain,
  :user,
  :password,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = [:password]
  include Aws::Structure
end