Class: Aws::DataSync::Types::UpdateLocationHdfsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datasync/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_arnsArray<String>

The Amazon Resource Names (ARNs) of the DataSync agents that can connect to your HDFS cluster.

Returns:

  • (Array<String>)


6285
6286
6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
# File 'lib/aws-sdk-datasync/types.rb', line 6285

class UpdateLocationHdfsRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#authentication_typeString

The type of authentication used to determine the identity of the user.

Returns:

  • (String)


6285
6286
6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
# File 'lib/aws-sdk-datasync/types.rb', line 6285

class UpdateLocationHdfsRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#block_sizeInteger

The size of the data blocks to write into the HDFS cluster.

Returns:

  • (Integer)


6285
6286
6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
# File 'lib/aws-sdk-datasync/types.rb', line 6285

class UpdateLocationHdfsRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#cmk_secret_configTypes::CmkSecretConfig

Specifies configuration information for a DataSync-managed secret, such as a KerberosKeytab or set of credentials that DataSync uses to access a specific transfer location, and a customer-managed KMS key.



6285
6286
6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
# File 'lib/aws-sdk-datasync/types.rb', line 6285

class UpdateLocationHdfsRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#custom_secret_configTypes::CustomSecretConfig

Specifies configuration information for a customer-managed secret, such as a KerberosKeytab or set of credentials that DataSync uses to access a specific transfer location, and a customer-managed Identity and Access Management (IAM) role that provides access to the secret.



6285
6286
6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
# File 'lib/aws-sdk-datasync/types.rb', line 6285

class UpdateLocationHdfsRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#kerberos_keytabString

The Kerberos key table (keytab) that contains mappings between the defined Kerberos principal and the encrypted keys. You can load the keytab from a file by providing the file’s address.

Returns:

  • (String)


6285
6286
6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
# File 'lib/aws-sdk-datasync/types.rb', line 6285

class UpdateLocationHdfsRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#kerberos_krb_5_confString

The krb5.conf file that contains the Kerberos configuration information. You can load the krb5.conf file by providing the file’s address. If you’re using the CLI, it performs the base64 encoding for you. Otherwise, provide the base64-encoded text.

Returns:

  • (String)


6285
6286
6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
# File 'lib/aws-sdk-datasync/types.rb', line 6285

class UpdateLocationHdfsRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#kerberos_principalString

The Kerberos principal with access to the files and folders on the HDFS cluster.

Returns:

  • (String)


6285
6286
6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
# File 'lib/aws-sdk-datasync/types.rb', line 6285

class UpdateLocationHdfsRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_provider_uriString

The URI of the HDFS cluster’s Key Management Server (KMS).

Returns:

  • (String)


6285
6286
6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
# File 'lib/aws-sdk-datasync/types.rb', line 6285

class UpdateLocationHdfsRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#location_arnString

The Amazon Resource Name (ARN) of the source HDFS cluster location.

Returns:

  • (String)


6285
6286
6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
# File 'lib/aws-sdk-datasync/types.rb', line 6285

class UpdateLocationHdfsRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#name_nodesArray<Types::HdfsNameNode>

The NameNode that manages the HDFS namespace. The NameNode performs operations such as opening, closing, and renaming files and directories. The NameNode contains the information to map blocks of data to the DataNodes. You can use only one NameNode.

Returns:



6285
6286
6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
# File 'lib/aws-sdk-datasync/types.rb', line 6285

class UpdateLocationHdfsRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#qop_configurationTypes::QopConfiguration

The Quality of Protection (QOP) configuration specifies the Remote Procedure Call (RPC) and data transfer privacy settings configured on the Hadoop Distributed File System (HDFS) cluster.



6285
6286
6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
# File 'lib/aws-sdk-datasync/types.rb', line 6285

class UpdateLocationHdfsRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#replication_factorInteger

The number of DataNodes to replicate the data to when writing to the HDFS cluster.

Returns:

  • (Integer)


6285
6286
6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
# File 'lib/aws-sdk-datasync/types.rb', line 6285

class UpdateLocationHdfsRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#simple_userString

The user name used to identify the client on the host operating system.

Returns:

  • (String)


6285
6286
6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
# File 'lib/aws-sdk-datasync/types.rb', line 6285

class UpdateLocationHdfsRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end

#subdirectoryString

A subdirectory in the HDFS cluster. This subdirectory is used to read data from or write data to the HDFS cluster.

Returns:

  • (String)


6285
6286
6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
# File 'lib/aws-sdk-datasync/types.rb', line 6285

class UpdateLocationHdfsRequest < Struct.new(
  :location_arn,
  :subdirectory,
  :name_nodes,
  :block_size,
  :replication_factor,
  :kms_key_provider_uri,
  :qop_configuration,
  :authentication_type,
  :simple_user,
  :kerberos_principal,
  :kerberos_keytab,
  :kerberos_krb_5_conf,
  :agent_arns,
  :cmk_secret_config,
  :custom_secret_config)
  SENSITIVE = []
  include Aws::Structure
end