Class: Aws::DataSync::Types::UpdateLocationNfsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataSync::Types::UpdateLocationNfsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datasync/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#location_arn ⇒ String
Specifies the Amazon Resource Name (ARN) of the NFS transfer location that you want to update.
-
#mount_options ⇒ Types::NfsMountOptions
Specifies how DataSync can access a location using the NFS protocol.
-
#on_prem_config ⇒ Types::OnPremConfig
The DataSync agents that can connect to your Network File System (NFS) file server.
-
#server_hostname ⇒ String
Specifies the DNS name or IP address (IPv4 or IPv6) of the NFS file server that your DataSync agent connects to.
-
#subdirectory ⇒ String
Specifies the export path in your NFS file server that you want DataSync to mount.
Instance Attribute Details
#location_arn ⇒ String
Specifies the Amazon Resource Name (ARN) of the NFS transfer location that you want to update.
6366 6367 6368 6369 6370 6371 6372 6373 6374 |
# File 'lib/aws-sdk-datasync/types.rb', line 6366 class UpdateLocationNfsRequest < Struct.new( :location_arn, :subdirectory, :server_hostname, :on_prem_config, :mount_options) SENSITIVE = [] include Aws::Structure end |
#mount_options ⇒ Types::NfsMountOptions
Specifies how DataSync can access a location using the NFS protocol.
6366 6367 6368 6369 6370 6371 6372 6373 6374 |
# File 'lib/aws-sdk-datasync/types.rb', line 6366 class UpdateLocationNfsRequest < Struct.new( :location_arn, :subdirectory, :server_hostname, :on_prem_config, :mount_options) SENSITIVE = [] include Aws::Structure end |
#on_prem_config ⇒ Types::OnPremConfig
The DataSync agents that can connect to your Network File System (NFS) file server.
6366 6367 6368 6369 6370 6371 6372 6373 6374 |
# File 'lib/aws-sdk-datasync/types.rb', line 6366 class UpdateLocationNfsRequest < Struct.new( :location_arn, :subdirectory, :server_hostname, :on_prem_config, :mount_options) SENSITIVE = [] include Aws::Structure end |
#server_hostname ⇒ String
Specifies the DNS name or IP address (IPv4 or IPv6) of the NFS file server that your DataSync agent connects to.
6366 6367 6368 6369 6370 6371 6372 6373 6374 |
# File 'lib/aws-sdk-datasync/types.rb', line 6366 class UpdateLocationNfsRequest < Struct.new( :location_arn, :subdirectory, :server_hostname, :on_prem_config, :mount_options) SENSITIVE = [] include Aws::Structure end |
#subdirectory ⇒ String
Specifies the export path in your NFS file server that you want DataSync to mount.
This path (or a subdirectory of the path) is where DataSync transfers data to or from. For information on configuring an export for DataSync, see Accessing NFS file servers.
6366 6367 6368 6369 6370 6371 6372 6373 6374 |
# File 'lib/aws-sdk-datasync/types.rb', line 6366 class UpdateLocationNfsRequest < Struct.new( :location_arn, :subdirectory, :server_hostname, :on_prem_config, :mount_options) SENSITIVE = [] include Aws::Structure end |