Class: Aws::DataSync::Types::UpdateLocationObjectStorageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataSync::Types::UpdateLocationObjectStorageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datasync/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:secret_key]
Instance Attribute Summary collapse
-
#access_key ⇒ String
Specifies the access key (for example, a user name) if credentials are required to authenticate with the object storage server.
-
#agent_arns ⇒ Array<String>
(Optional) Specifies the Amazon Resource Names (ARNs) of the DataSync agents that can connect with your object storage system.
-
#cmk_secret_config ⇒ Types::CmkSecretConfig
Specifies configuration information for a DataSync-managed secret, such as an authentication token or set of credentials that DataSync uses to access a specific transfer location, and a customer-managed KMS key.
-
#custom_secret_config ⇒ Types::CustomSecretConfig
Specifies configuration information for a customer-managed secret, such as an authentication token or set of credentials that DataSync uses to access a specific transfer location, and a customer-managed Identity and Access Management (IAM) role that provides access to the secret.
-
#location_arn ⇒ String
Specifies the ARN of the object storage system location that you’re updating.
-
#secret_key ⇒ String
Specifies the secret key (for example, a password) if credentials are required to authenticate with the object storage server.
-
#server_certificate ⇒ String
Specifies a certificate chain for DataSync to authenticate with your object storage system if the system uses a private or self-signed certificate authority (CA).
-
#server_hostname ⇒ String
Specifies the domain name or IP address (IPv4 or IPv6) of the object storage server that your DataSync agent connects to.
-
#server_port ⇒ Integer
Specifies the port that your object storage server accepts inbound network traffic on (for example, port 443).
-
#server_protocol ⇒ String
Specifies the protocol that your object storage server uses to communicate.
-
#subdirectory ⇒ String
Specifies the object prefix for your object storage server.
Instance Attribute Details
#access_key ⇒ String
Specifies the access key (for example, a user name) if credentials are required to authenticate with the object storage server.
6459 6460 6461 6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 |
# File 'lib/aws-sdk-datasync/types.rb', line 6459 class UpdateLocationObjectStorageRequest < Struct.new( :location_arn, :server_port, :server_protocol, :subdirectory, :server_hostname, :access_key, :secret_key, :agent_arns, :server_certificate, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:secret_key] include Aws::Structure end |
#agent_arns ⇒ Array<String>
(Optional) Specifies the Amazon Resource Names (ARNs) of the DataSync agents that can connect with your object storage system. If you are setting up an agentless cross-cloud transfer, you do not need to specify a value for this parameter.
<note markdown=“1”> You cannot add or remove agents from a storage location after you initially create it.
</note>
6459 6460 6461 6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 |
# File 'lib/aws-sdk-datasync/types.rb', line 6459 class UpdateLocationObjectStorageRequest < Struct.new( :location_arn, :server_port, :server_protocol, :subdirectory, :server_hostname, :access_key, :secret_key, :agent_arns, :server_certificate, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:secret_key] include Aws::Structure end |
#cmk_secret_config ⇒ Types::CmkSecretConfig
Specifies configuration information for a DataSync-managed secret, such as an authentication token or set of credentials that DataSync uses to access a specific transfer location, and a customer-managed KMS key.
6459 6460 6461 6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 |
# File 'lib/aws-sdk-datasync/types.rb', line 6459 class UpdateLocationObjectStorageRequest < Struct.new( :location_arn, :server_port, :server_protocol, :subdirectory, :server_hostname, :access_key, :secret_key, :agent_arns, :server_certificate, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:secret_key] include Aws::Structure end |
#custom_secret_config ⇒ Types::CustomSecretConfig
Specifies configuration information for a customer-managed secret, such as an authentication token or set of credentials that DataSync uses to access a specific transfer location, and a customer-managed Identity and Access Management (IAM) role that provides access to the secret.
6459 6460 6461 6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 |
# File 'lib/aws-sdk-datasync/types.rb', line 6459 class UpdateLocationObjectStorageRequest < Struct.new( :location_arn, :server_port, :server_protocol, :subdirectory, :server_hostname, :access_key, :secret_key, :agent_arns, :server_certificate, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:secret_key] include Aws::Structure end |
#location_arn ⇒ String
Specifies the ARN of the object storage system location that you’re updating.
6459 6460 6461 6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 |
# File 'lib/aws-sdk-datasync/types.rb', line 6459 class UpdateLocationObjectStorageRequest < Struct.new( :location_arn, :server_port, :server_protocol, :subdirectory, :server_hostname, :access_key, :secret_key, :agent_arns, :server_certificate, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:secret_key] include Aws::Structure end |
#secret_key ⇒ String
Specifies the secret key (for example, a password) if credentials are required to authenticate with the object storage server.
<note markdown=“1”> If you provide a secret using SecretKey, but do not provide secret configuration details using CmkSecretConfig or CustomSecretConfig, then DataSync stores the token using your Amazon Web Services account’s Secrets Manager secret.
</note>
6459 6460 6461 6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 |
# File 'lib/aws-sdk-datasync/types.rb', line 6459 class UpdateLocationObjectStorageRequest < Struct.new( :location_arn, :server_port, :server_protocol, :subdirectory, :server_hostname, :access_key, :secret_key, :agent_arns, :server_certificate, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:secret_key] include Aws::Structure end |
#server_certificate ⇒ String
Specifies a certificate chain for DataSync to authenticate with your object storage system if the system uses a private or self-signed certificate authority (CA). You must specify a single .pem file with a full certificate chain (for example, file:///home/user/.ssh/object_storage_certificates.pem).
The certificate chain might include:
-
The object storage system’s certificate
-
All intermediate certificates (if there are any)
-
The root certificate of the signing CA
You can concatenate your certificates into a .pem file (which can be up to 32768 bytes before base64 encoding). The following example cat command creates an object_storage_certificates.pem file that includes three certificates:
‘cat object_server_certificate.pem intermediate_certificate.pem ca_root_certificate.pem > object_storage_certificates.pem`
To use this parameter, configure ServerProtocol to HTTPS.
Updating this parameter doesn’t interfere with tasks that you have in progress.
6459 6460 6461 6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 |
# File 'lib/aws-sdk-datasync/types.rb', line 6459 class UpdateLocationObjectStorageRequest < Struct.new( :location_arn, :server_port, :server_protocol, :subdirectory, :server_hostname, :access_key, :secret_key, :agent_arns, :server_certificate, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:secret_key] include Aws::Structure end |
#server_hostname ⇒ String
Specifies the domain name or IP address (IPv4 or IPv6) of the object storage server that your DataSync agent connects to.
6459 6460 6461 6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 |
# File 'lib/aws-sdk-datasync/types.rb', line 6459 class UpdateLocationObjectStorageRequest < Struct.new( :location_arn, :server_port, :server_protocol, :subdirectory, :server_hostname, :access_key, :secret_key, :agent_arns, :server_certificate, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:secret_key] include Aws::Structure end |
#server_port ⇒ Integer
Specifies the port that your object storage server accepts inbound network traffic on (for example, port 443).
6459 6460 6461 6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 |
# File 'lib/aws-sdk-datasync/types.rb', line 6459 class UpdateLocationObjectStorageRequest < Struct.new( :location_arn, :server_port, :server_protocol, :subdirectory, :server_hostname, :access_key, :secret_key, :agent_arns, :server_certificate, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:secret_key] include Aws::Structure end |
#server_protocol ⇒ String
Specifies the protocol that your object storage server uses to communicate.
6459 6460 6461 6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 |
# File 'lib/aws-sdk-datasync/types.rb', line 6459 class UpdateLocationObjectStorageRequest < Struct.new( :location_arn, :server_port, :server_protocol, :subdirectory, :server_hostname, :access_key, :secret_key, :agent_arns, :server_certificate, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:secret_key] include Aws::Structure end |
#subdirectory ⇒ String
Specifies the object prefix for your object storage server. If this is a source location, DataSync only copies objects with this prefix. If this is a destination location, DataSync writes all objects with this prefix.
6459 6460 6461 6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 |
# File 'lib/aws-sdk-datasync/types.rb', line 6459 class UpdateLocationObjectStorageRequest < Struct.new( :location_arn, :server_port, :server_protocol, :subdirectory, :server_hostname, :access_key, :secret_key, :agent_arns, :server_certificate, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:secret_key] include Aws::Structure end |