Class: Aws::DataSync::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::DataSync::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-datasync/client.rb
Overview
An API client for DataSync. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::DataSync::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_task_execution(params = {}) ⇒ Struct
Stops an DataSync task execution that’s in progress.
-
#create_agent(params = {}) ⇒ Types::CreateAgentResponse
Activates an DataSync agent that you deploy in your storage environment.
-
#create_location_azure_blob(params = {}) ⇒ Types::CreateLocationAzureBlobResponse
Creates a transfer location for a Microsoft Azure Blob Storage container.
-
#create_location_efs(params = {}) ⇒ Types::CreateLocationEfsResponse
Creates a transfer location for an Amazon EFS file system.
-
#create_location_fsx_lustre(params = {}) ⇒ Types::CreateLocationFsxLustreResponse
Creates a transfer location for an Amazon FSx for Lustre file system.
-
#create_location_fsx_ontap(params = {}) ⇒ Types::CreateLocationFsxOntapResponse
Creates a transfer location for an Amazon FSx for NetApp ONTAP file system.
-
#create_location_fsx_open_zfs(params = {}) ⇒ Types::CreateLocationFsxOpenZfsResponse
Creates a transfer location for an Amazon FSx for OpenZFS file system.
-
#create_location_fsx_windows(params = {}) ⇒ Types::CreateLocationFsxWindowsResponse
Creates a transfer location for an Amazon FSx for Windows File Server file system.
-
#create_location_hdfs(params = {}) ⇒ Types::CreateLocationHdfsResponse
Creates a transfer location for a Hadoop Distributed File System (HDFS).
-
#create_location_nfs(params = {}) ⇒ Types::CreateLocationNfsResponse
Creates a transfer location for a Network File System (NFS) file server.
-
#create_location_object_storage(params = {}) ⇒ Types::CreateLocationObjectStorageResponse
Creates a transfer location for an object storage system.
-
#create_location_s3(params = {}) ⇒ Types::CreateLocationS3Response
Creates a transfer location for an Amazon S3 bucket.
-
#create_location_smb(params = {}) ⇒ Types::CreateLocationSmbResponse
Creates a transfer location for a Server Message Block (SMB) file server.
-
#create_task(params = {}) ⇒ Types::CreateTaskResponse
Configures a task, which defines where and how DataSync transfers your data.
-
#delete_agent(params = {}) ⇒ Struct
Removes an DataSync agent resource from your Amazon Web Services account.
-
#delete_location(params = {}) ⇒ Struct
Deletes a transfer location resource from DataSync.
-
#delete_task(params = {}) ⇒ Struct
Deletes a transfer task resource from DataSync.
-
#describe_agent(params = {}) ⇒ Types::DescribeAgentResponse
Returns information about an DataSync agent, such as its name, service endpoint type, and status.
-
#describe_location_azure_blob(params = {}) ⇒ Types::DescribeLocationAzureBlobResponse
Provides details about how an DataSync transfer location for Microsoft Azure Blob Storage is configured.
-
#describe_location_efs(params = {}) ⇒ Types::DescribeLocationEfsResponse
Provides details about how an DataSync transfer location for an Amazon EFS file system is configured.
-
#describe_location_fsx_lustre(params = {}) ⇒ Types::DescribeLocationFsxLustreResponse
Provides details about how an DataSync transfer location for an Amazon FSx for Lustre file system is configured.
-
#describe_location_fsx_ontap(params = {}) ⇒ Types::DescribeLocationFsxOntapResponse
Provides details about how an DataSync transfer location for an Amazon FSx for NetApp ONTAP file system is configured.
-
#describe_location_fsx_open_zfs(params = {}) ⇒ Types::DescribeLocationFsxOpenZfsResponse
Provides details about how an DataSync transfer location for an Amazon FSx for OpenZFS file system is configured.
-
#describe_location_fsx_windows(params = {}) ⇒ Types::DescribeLocationFsxWindowsResponse
Provides details about how an DataSync transfer location for an Amazon FSx for Windows File Server file system is configured.
-
#describe_location_hdfs(params = {}) ⇒ Types::DescribeLocationHdfsResponse
Provides details about how an DataSync transfer location for a Hadoop Distributed File System (HDFS) is configured.
-
#describe_location_nfs(params = {}) ⇒ Types::DescribeLocationNfsResponse
Provides details about how an DataSync transfer location for a Network File System (NFS) file server is configured.
-
#describe_location_object_storage(params = {}) ⇒ Types::DescribeLocationObjectStorageResponse
Provides details about how an DataSync transfer location for an object storage system is configured.
-
#describe_location_s3(params = {}) ⇒ Types::DescribeLocationS3Response
Provides details about how an DataSync transfer location for an S3 bucket is configured.
-
#describe_location_smb(params = {}) ⇒ Types::DescribeLocationSmbResponse
Provides details about how an DataSync transfer location for a Server Message Block (SMB) file server is configured.
-
#describe_task(params = {}) ⇒ Types::DescribeTaskResponse
Provides information about a task, which defines where and how DataSync transfers your data.
-
#describe_task_execution(params = {}) ⇒ Types::DescribeTaskExecutionResponse
Provides information about an execution of your DataSync task.
-
#list_agents(params = {}) ⇒ Types::ListAgentsResponse
Returns a list of DataSync agents that belong to an Amazon Web Services account in the Amazon Web Services Region specified in the request.
-
#list_locations(params = {}) ⇒ Types::ListLocationsResponse
Returns a list of source and destination locations.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns all the tags associated with an Amazon Web Services resource.
-
#list_task_executions(params = {}) ⇒ Types::ListTaskExecutionsResponse
Returns a list of executions for an DataSync transfer task.
-
#list_tasks(params = {}) ⇒ Types::ListTasksResponse
Returns a list of the DataSync tasks you created.
-
#start_task_execution(params = {}) ⇒ Types::StartTaskExecutionResponse
Starts an DataSync transfer task.
-
#tag_resource(params = {}) ⇒ Struct
Applies a tag to an Amazon Web Services resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from an Amazon Web Services resource.
-
#update_agent(params = {}) ⇒ Struct
Updates the name of an DataSync agent.
-
#update_location_azure_blob(params = {}) ⇒ Struct
Modifies the following configurations of the Microsoft Azure Blob Storage transfer location that you’re using with DataSync.
-
#update_location_efs(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Amazon EFS transfer location that you’re using with DataSync.
-
#update_location_fsx_lustre(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Amazon FSx for Lustre transfer location that you’re using with DataSync.
-
#update_location_fsx_ontap(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Amazon FSx for NetApp ONTAP transfer location that you’re using with DataSync.
-
#update_location_fsx_open_zfs(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Amazon FSx for OpenZFS transfer location that you’re using with DataSync.
-
#update_location_fsx_windows(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Amazon FSx for Windows File Server transfer location that you’re using with DataSync.
-
#update_location_hdfs(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Hadoop Distributed File System (HDFS) transfer location that you’re using with DataSync.
-
#update_location_nfs(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Network File System (NFS) transfer location that you’re using with DataSync.
-
#update_location_object_storage(params = {}) ⇒ Struct
Modifies the following configuration parameters of the object storage transfer location that you’re using with DataSync.
-
#update_location_s3(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Amazon S3 transfer location that you’re using with DataSync.
-
#update_location_smb(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Server Message Block (SMB) transfer location that you’re using with DataSync.
-
#update_task(params = {}) ⇒ Struct
Updates the configuration of a task, which defines where and how DataSync transfers your data.
-
#update_task_execution(params = {}) ⇒ Struct
Updates the configuration of a running DataSync task execution.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-datasync/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5168 5169 5170 |
# File 'lib/aws-sdk-datasync/client.rb', line 5168 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5171 5172 5173 |
# File 'lib/aws-sdk-datasync/client.rb', line 5171 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 |
# File 'lib/aws-sdk-datasync/client.rb', line 5141 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::DataSync') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-datasync' context[:gem_version] = '1.125.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_task_execution(params = {}) ⇒ Struct
Stops an DataSync task execution that’s in progress. The transfer of some files are abruptly interrupted. File contents that’re transferred to the destination might be incomplete or inconsistent with the source files.
However, if you start a new task execution using the same task and allow it to finish, file content on the destination will be complete and consistent. This applies to other unexpected failures that interrupt a task execution. In all of these cases, DataSync successfully completes the transfer when you start the next task execution.
511 512 513 514 |
# File 'lib/aws-sdk-datasync/client.rb', line 511 def cancel_task_execution(params = {}, = {}) req = build_request(:cancel_task_execution, params) req.send_request() end |
#create_agent(params = {}) ⇒ Types::CreateAgentResponse
Activates an DataSync agent that you deploy in your storage environment. The activation process associates the agent with your Amazon Web Services account.
If you haven’t deployed an agent yet, see [Do I need a DataSync agent?]
[1]: docs.aws.amazon.com/datasync/latest/userguide/do-i-need-datasync-agent.html
592 593 594 595 |
# File 'lib/aws-sdk-datasync/client.rb', line 592 def create_agent(params = {}, = {}) req = build_request(:create_agent, params) req.send_request() end |
#create_location_azure_blob(params = {}) ⇒ Types::CreateLocationAzureBlobResponse
Creates a transfer location for a Microsoft Azure Blob Storage container. DataSync can use this location as a transfer source or destination. You can make transfers with or without a [DataSync agent] that connects to your container.
Before you begin, make sure you know [how DataSync accesses Azure Blob Storage] and works with [access tiers] and [blob types].
[1]: docs.aws.amazon.com/datasync/latest/userguide/creating-azure-blob-location.html#azure-blob-creating-agent [2]: docs.aws.amazon.com/datasync/latest/userguide/creating-azure-blob-location.html#azure-blob-access [3]: docs.aws.amazon.com/datasync/latest/userguide/creating-azure-blob-location.html#azure-blob-access-tiers [4]: docs.aws.amazon.com/datasync/latest/userguide/creating-azure-blob-location.html#blob-types
765 766 767 768 |
# File 'lib/aws-sdk-datasync/client.rb', line 765 def create_location_azure_blob(params = {}, = {}) req = build_request(:create_location_azure_blob, params) req.send_request() end |
#create_location_efs(params = {}) ⇒ Types::CreateLocationEfsResponse
Creates a transfer location for an Amazon EFS file system. DataSync can use this location as a source or destination for transferring data.
Before you begin, make sure that you understand how DataSync [accesses Amazon EFS file systems].
[1]: docs.aws.amazon.com/datasync/latest/userguide/create-efs-location.html#create-efs-location-access
873 874 875 876 |
# File 'lib/aws-sdk-datasync/client.rb', line 873 def create_location_efs(params = {}, = {}) req = build_request(:create_location_efs, params) req.send_request() end |
#create_location_fsx_lustre(params = {}) ⇒ Types::CreateLocationFsxLustreResponse
Creates a transfer location for an Amazon FSx for Lustre file system. DataSync can use this location as a source or destination for transferring data.
Before you begin, make sure that you understand how DataSync [accesses FSx for Lustre file systems].
946 947 948 949 |
# File 'lib/aws-sdk-datasync/client.rb', line 946 def create_location_fsx_lustre(params = {}, = {}) req = build_request(:create_location_fsx_lustre, params) req.send_request() end |
#create_location_fsx_ontap(params = {}) ⇒ Types::CreateLocationFsxOntapResponse
Creates a transfer location for an Amazon FSx for NetApp ONTAP file system. DataSync can use this location as a source or destination for transferring data.
Before you begin, make sure that you understand how DataSync [accesses FSx for ONTAP file systems].
1060 1061 1062 1063 |
# File 'lib/aws-sdk-datasync/client.rb', line 1060 def create_location_fsx_ontap(params = {}, = {}) req = build_request(:create_location_fsx_ontap, params) req.send_request() end |
#create_location_fsx_open_zfs(params = {}) ⇒ Types::CreateLocationFsxOpenZfsResponse
Creates a transfer location for an Amazon FSx for OpenZFS file system. DataSync can use this location as a source or destination for transferring data.
Before you begin, make sure that you understand how DataSync [accesses FSx for OpenZFS file systems].
<note markdown=“1”> Request parameters related to ‘SMB` aren’t supported with the ‘CreateLocationFsxOpenZfs` operation.
</note>
[1]: docs.aws.amazon.com/datasync/latest/userguide/create-openzfs-location.html#create-openzfs-access
1154 1155 1156 1157 |
# File 'lib/aws-sdk-datasync/client.rb', line 1154 def create_location_fsx_open_zfs(params = {}, = {}) req = build_request(:create_location_fsx_open_zfs, params) req.send_request() end |
#create_location_fsx_windows(params = {}) ⇒ Types::CreateLocationFsxWindowsResponse
Creates a transfer location for an Amazon FSx for Windows File Server file system. DataSync can use this location as a source or destination for transferring data.
Before you begin, make sure that you understand how DataSync [accesses FSx for Windows File Server file systems].
[1]: docs.aws.amazon.com/datasync/latest/userguide/create-fsx-location.html#create-fsx-location-access
1316 1317 1318 1319 |
# File 'lib/aws-sdk-datasync/client.rb', line 1316 def create_location_fsx_windows(params = {}, = {}) req = build_request(:create_location_fsx_windows, params) req.send_request() end |
#create_location_hdfs(params = {}) ⇒ Types::CreateLocationHdfsResponse
Creates a transfer location for a Hadoop Distributed File System (HDFS). DataSync can use this location as a source or destination for transferring data.
Before you begin, make sure that you understand how DataSync [accesses HDFS clusters].
[1]: docs.aws.amazon.com/datasync/latest/userguide/create-hdfs-location.html#accessing-hdfs
1511 1512 1513 1514 |
# File 'lib/aws-sdk-datasync/client.rb', line 1511 def create_location_hdfs(params = {}, = {}) req = build_request(:create_location_hdfs, params) req.send_request() end |
#create_location_nfs(params = {}) ⇒ Types::CreateLocationNfsResponse
Creates a transfer location for a Network File System (NFS) file server. DataSync can use this location as a source or destination for transferring data.
Before you begin, make sure that you understand how DataSync [accesses NFS file servers].
[1]: docs.aws.amazon.com/datasync/latest/userguide/create-nfs-location.html#accessing-nfs
1594 1595 1596 1597 |
# File 'lib/aws-sdk-datasync/client.rb', line 1594 def create_location_nfs(params = {}, = {}) req = build_request(:create_location_nfs, params) req.send_request() end |
#create_location_object_storage(params = {}) ⇒ Types::CreateLocationObjectStorageResponse
Creates a transfer location for an object storage system. DataSync can use this location as a source or destination for transferring data. You can make transfers with or without a [DataSync agent].
Before you begin, make sure that you understand the [prerequisites] for DataSync to work with object storage systems.
[1]: docs.aws.amazon.com/datasync/latest/userguide/do-i-need-datasync-agent.html#when-agent-required [2]: docs.aws.amazon.com/datasync/latest/userguide/create-object-location.html#create-object-location-prerequisites
1775 1776 1777 1778 |
# File 'lib/aws-sdk-datasync/client.rb', line 1775 def create_location_object_storage(params = {}, = {}) req = build_request(:create_location_object_storage, params) req.send_request() end |
#create_location_s3(params = {}) ⇒ Types::CreateLocationS3Response
Creates a transfer location for an Amazon S3 bucket. DataSync can use this location as a source or destination for transferring data.
Before you begin, make sure that you read the following topics:
* [Storage class considerations with Amazon S3 locations][1]
- Evaluating S3 request costs when using DataSync][2
For more information, see [Configuring transfers with Amazon S3].
[1]: docs.aws.amazon.com/datasync/latest/userguide/create-s3-location.html#using-storage-classes [2]: docs.aws.amazon.com/datasync/latest/userguide/create-s3-location.html#create-s3-location-s3-requests [3]: docs.aws.amazon.com/datasync/latest/userguide/create-s3-location.html
1899 1900 1901 1902 |
# File 'lib/aws-sdk-datasync/client.rb', line 1899 def create_location_s3(params = {}, = {}) req = build_request(:create_location_s3, params) req.send_request() end |
#create_location_smb(params = {}) ⇒ Types::CreateLocationSmbResponse
Creates a transfer location for a Server Message Block (SMB) file server. DataSync can use this location as a source or destination for transferring data.
Before you begin, make sure that you understand how DataSync accesses SMB file servers. For more information, see [Providing DataSync access to SMB file servers].
[1]: docs.aws.amazon.com/datasync/latest/userguide/create-smb-location.html#configuring-smb-permissions
2121 2122 2123 2124 |
# File 'lib/aws-sdk-datasync/client.rb', line 2121 def create_location_smb(params = {}, = {}) req = build_request(:create_location_smb, params) req.send_request() end |
#create_task(params = {}) ⇒ Types::CreateTaskResponse
Configures a task, which defines where and how DataSync transfers your data.
A task includes a source location, destination location, and transfer options (such as bandwidth limits, scheduling, and more).
If you’re planning to transfer data to or from an Amazon S3 location, review [how DataSync can affect your S3 request charges] and the
- DataSync pricing page][2
-
before you begin.
[1]: docs.aws.amazon.com/datasync/latest/userguide/create-s3-location.html#create-s3-location-s3-requests [2]: aws.amazon.com/datasync/pricing/
2356 2357 2358 2359 |
# File 'lib/aws-sdk-datasync/client.rb', line 2356 def create_task(params = {}, = {}) req = build_request(:create_task, params) req.send_request() end |
#delete_agent(params = {}) ⇒ Struct
Removes an DataSync agent resource from your Amazon Web Services account.
Keep in mind that this operation (which can’t be undone) doesn’t remove the agent’s virtual machine (VM) or Amazon EC2 instance from your storage environment. For next steps, you can delete the VM or instance from your storage environment or reuse it to [activate a new agent].
[1]: docs.aws.amazon.com/datasync/latest/userguide/activate-agent.html
2391 2392 2393 2394 |
# File 'lib/aws-sdk-datasync/client.rb', line 2391 def delete_agent(params = {}, = {}) req = build_request(:delete_agent, params) req.send_request() end |
#delete_location(params = {}) ⇒ Struct
Deletes a transfer location resource from DataSync.
2413 2414 2415 2416 |
# File 'lib/aws-sdk-datasync/client.rb', line 2413 def delete_location(params = {}, = {}) req = build_request(:delete_location, params) req.send_request() end |
#delete_task(params = {}) ⇒ Struct
Deletes a transfer task resource from DataSync.
2436 2437 2438 2439 |
# File 'lib/aws-sdk-datasync/client.rb', line 2436 def delete_task(params = {}, = {}) req = build_request(:delete_task, params) req.send_request() end |
#describe_agent(params = {}) ⇒ Types::DescribeAgentResponse
Returns information about an DataSync agent, such as its name, service endpoint type, and status.
2485 2486 2487 2488 |
# File 'lib/aws-sdk-datasync/client.rb', line 2485 def describe_agent(params = {}, = {}) req = build_request(:describe_agent, params) req.send_request() end |
#describe_location_azure_blob(params = {}) ⇒ Types::DescribeLocationAzureBlobResponse
Provides details about how an DataSync transfer location for Microsoft Azure Blob Storage is configured.
2536 2537 2538 2539 |
# File 'lib/aws-sdk-datasync/client.rb', line 2536 def describe_location_azure_blob(params = {}, = {}) req = build_request(:describe_location_azure_blob, params) req.send_request() end |
#describe_location_efs(params = {}) ⇒ Types::DescribeLocationEfsResponse
Provides details about how an DataSync transfer location for an Amazon EFS file system is configured.
2580 2581 2582 2583 |
# File 'lib/aws-sdk-datasync/client.rb', line 2580 def describe_location_efs(params = {}, = {}) req = build_request(:describe_location_efs, params) req.send_request() end |
#describe_location_fsx_lustre(params = {}) ⇒ Types::DescribeLocationFsxLustreResponse
Provides details about how an DataSync transfer location for an Amazon FSx for Lustre file system is configured.
2617 2618 2619 2620 |
# File 'lib/aws-sdk-datasync/client.rb', line 2617 def describe_location_fsx_lustre(params = {}, = {}) req = build_request(:describe_location_fsx_lustre, params) req.send_request() end |
#describe_location_fsx_ontap(params = {}) ⇒ Types::DescribeLocationFsxOntapResponse
Provides details about how an DataSync transfer location for an Amazon FSx for NetApp ONTAP file system is configured.
<note markdown=“1”> If your location uses SMB, the ‘DescribeLocationFsxOntap` operation doesn’t actually return a ‘Password`.
</note>
2674 2675 2676 2677 |
# File 'lib/aws-sdk-datasync/client.rb', line 2674 def describe_location_fsx_ontap(params = {}, = {}) req = build_request(:describe_location_fsx_ontap, params) req.send_request() end |
#describe_location_fsx_open_zfs(params = {}) ⇒ Types::DescribeLocationFsxOpenZfsResponse
Provides details about how an DataSync transfer location for an Amazon FSx for OpenZFS file system is configured.
<note markdown=“1”> Response elements related to ‘SMB` aren’t supported with the ‘DescribeLocationFsxOpenZfs` operation.
</note>
2727 2728 2729 2730 |
# File 'lib/aws-sdk-datasync/client.rb', line 2727 def describe_location_fsx_open_zfs(params = {}, = {}) req = build_request(:describe_location_fsx_open_zfs, params) req.send_request() end |
#describe_location_fsx_windows(params = {}) ⇒ Types::DescribeLocationFsxWindowsResponse
Provides details about how an DataSync transfer location for an Amazon FSx for Windows File Server file system is configured.
2776 2777 2778 2779 |
# File 'lib/aws-sdk-datasync/client.rb', line 2776 def describe_location_fsx_windows(params = {}, = {}) req = build_request(:describe_location_fsx_windows, params) req.send_request() end |
#describe_location_hdfs(params = {}) ⇒ Types::DescribeLocationHdfsResponse
Provides details about how an DataSync transfer location for a Hadoop Distributed File System (HDFS) is configured.
2839 2840 2841 2842 |
# File 'lib/aws-sdk-datasync/client.rb', line 2839 def describe_location_hdfs(params = {}, = {}) req = build_request(:describe_location_hdfs, params) req.send_request() end |
#describe_location_nfs(params = {}) ⇒ Types::DescribeLocationNfsResponse
Provides details about how an DataSync transfer location for a Network File System (NFS) file server is configured.
2878 2879 2880 2881 |
# File 'lib/aws-sdk-datasync/client.rb', line 2878 def describe_location_nfs(params = {}, = {}) req = build_request(:describe_location_nfs, params) req.send_request() end |
#describe_location_object_storage(params = {}) ⇒ Types::DescribeLocationObjectStorageResponse
Provides details about how an DataSync transfer location for an object storage system is configured.
2931 2932 2933 2934 |
# File 'lib/aws-sdk-datasync/client.rb', line 2931 def describe_location_object_storage(params = {}, = {}) req = build_request(:describe_location_object_storage, params) req.send_request() end |
#describe_location_s3(params = {}) ⇒ Types::DescribeLocationS3Response
Provides details about how an DataSync transfer location for an S3 bucket is configured.
2971 2972 2973 2974 |
# File 'lib/aws-sdk-datasync/client.rb', line 2971 def describe_location_s3(params = {}, = {}) req = build_request(:describe_location_s3, params) req.send_request() end |
#describe_location_smb(params = {}) ⇒ Types::DescribeLocationSmbResponse
Provides details about how an DataSync transfer location for a Server Message Block (SMB) file server is configured.
3029 3030 3031 3032 |
# File 'lib/aws-sdk-datasync/client.rb', line 3029 def describe_location_smb(params = {}, = {}) req = build_request(:describe_location_smb, params) req.send_request() end |
#describe_task(params = {}) ⇒ Types::DescribeTaskResponse
Provides information about a task, which defines where and how DataSync transfers your data.
3134 3135 3136 3137 |
# File 'lib/aws-sdk-datasync/client.rb', line 3134 def describe_task(params = {}, = {}) req = build_request(:describe_task, params) req.send_request() end |
#describe_task_execution(params = {}) ⇒ Types::DescribeTaskExecutionResponse
Provides information about an execution of your DataSync task. You can use this operation to help monitor the progress of an ongoing data transfer or check the results of the transfer.
<note markdown=“1”> Some ‘DescribeTaskExecution` response elements are only relevant to a specific task mode. For information, see [Understanding task mode differences] and [Understanding data transfer performance counters].
</note>
[1]: docs.aws.amazon.com/datasync/latest/userguide/choosing-task-mode.html#task-mode-differences [2]: docs.aws.amazon.com/datasync/latest/userguide/transfer-performance-counters.html
3296 3297 3298 3299 |
# File 'lib/aws-sdk-datasync/client.rb', line 3296 def describe_task_execution(params = {}, = {}) req = build_request(:describe_task_execution, params) req.send_request() end |
#list_agents(params = {}) ⇒ Types::ListAgentsResponse
Returns a list of DataSync agents that belong to an Amazon Web Services account in the Amazon Web Services Region specified in the request.
With pagination, you can reduce the number of agents returned in a response. If you get a truncated list of agents in a response, the response contains a marker that you can specify in your next request to fetch the next page of agents.
‘ListAgents` is eventually consistent. This means the result of running the operation might not reflect that you just created or deleted an agent. For example, if you create an agent with
- CreateAgent][1
-
and then immediately run ‘ListAgents`, that agent
might not show up in the list right away. In situations like this, you can always confirm whether an agent has been created (or deleted) by using [DescribeAgent].
[1]: docs.aws.amazon.com/datasync/latest/userguide/API_CreateAgent.html [2]: docs.aws.amazon.com/datasync/latest/userguide/API_DescribeAgent.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3358 3359 3360 3361 |
# File 'lib/aws-sdk-datasync/client.rb', line 3358 def list_agents(params = {}, = {}) req = build_request(:list_agents, params) req.send_request() end |
#list_locations(params = {}) ⇒ Types::ListLocationsResponse
Returns a list of source and destination locations.
If you have more locations than are returned in a response (that is, the response returns only a truncated list of your agents), the response contains a token that you can specify in your next request to fetch the next page of locations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3415 3416 3417 3418 |
# File 'lib/aws-sdk-datasync/client.rb', line 3415 def list_locations(params = {}, = {}) req = build_request(:list_locations, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns all the tags associated with an Amazon Web Services resource.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3459 3460 3461 3462 |
# File 'lib/aws-sdk-datasync/client.rb', line 3459 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_task_executions(params = {}) ⇒ Types::ListTaskExecutionsResponse
Returns a list of executions for an DataSync transfer task.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3504 3505 3506 3507 |
# File 'lib/aws-sdk-datasync/client.rb', line 3504 def list_task_executions(params = {}, = {}) req = build_request(:list_task_executions, params) req.send_request() end |
#list_tasks(params = {}) ⇒ Types::ListTasksResponse
Returns a list of the DataSync tasks you created.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3558 3559 3560 3561 |
# File 'lib/aws-sdk-datasync/client.rb', line 3558 def list_tasks(params = {}, = {}) req = build_request(:list_tasks, params) req.send_request() end |
#start_task_execution(params = {}) ⇒ Types::StartTaskExecutionResponse
Starts an DataSync transfer task. For each task, you can only run one task execution at a time.
There are several steps to a task execution. For more information, see [Task execution statuses].
If you’re planning to transfer data to or from an Amazon S3 location, review [how DataSync can affect your S3 request charges] and the
- DataSync pricing page][3
-
before you begin.
[1]: docs.aws.amazon.com/datasync/latest/userguide/working-with-task-executions.html#understand-task-execution-statuses [2]: docs.aws.amazon.com/datasync/latest/userguide/create-s3-location.html#create-s3-location-s3-requests [3]: aws.amazon.com/datasync/pricing/
3747 3748 3749 3750 |
# File 'lib/aws-sdk-datasync/client.rb', line 3747 def start_task_execution(params = {}, = {}) req = build_request(:start_task_execution, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Applies a tag to an Amazon Web Services resource. Tags are key-value pairs that can help you manage, filter, and search for your resources.
These include DataSync resources, such as locations, tasks, and task executions.
3783 3784 3785 3786 |
# File 'lib/aws-sdk-datasync/client.rb', line 3783 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from an Amazon Web Services resource.
3810 3811 3812 3813 |
# File 'lib/aws-sdk-datasync/client.rb', line 3810 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_agent(params = {}) ⇒ Struct
Updates the name of an DataSync agent.
3836 3837 3838 3839 |
# File 'lib/aws-sdk-datasync/client.rb', line 3836 def update_agent(params = {}, = {}) req = build_request(:update_agent, params) req.send_request() end |
#update_location_azure_blob(params = {}) ⇒ Struct
Modifies the following configurations of the Microsoft Azure Blob Storage transfer location that you’re using with DataSync.
For more information, see [Configuring DataSync transfers with Azure Blob Storage].
[1]: docs.aws.amazon.com/datasync/latest/userguide/creating-azure-blob-location.html
3947 3948 3949 3950 |
# File 'lib/aws-sdk-datasync/client.rb', line 3947 def update_location_azure_blob(params = {}, = {}) req = build_request(:update_location_azure_blob, params) req.send_request() end |
#update_location_efs(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Amazon EFS transfer location that you’re using with DataSync.
For more information, see [Configuring DataSync transfers with Amazon EFS].
[1]: docs.aws.amazon.com/datasync/latest/userguide/create-efs-location.html
4026 4027 4028 4029 |
# File 'lib/aws-sdk-datasync/client.rb', line 4026 def update_location_efs(params = {}, = {}) req = build_request(:update_location_efs, params) req.send_request() end |
#update_location_fsx_lustre(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Amazon FSx for Lustre transfer location that you’re using with DataSync.
For more information, see [Configuring DataSync transfers with FSx for Lustre].
[1]: docs.aws.amazon.com/datasync/latest/userguide/create-lustre-location.html
4067 4068 4069 4070 |
# File 'lib/aws-sdk-datasync/client.rb', line 4067 def update_location_fsx_lustre(params = {}, = {}) req = build_request(:update_location_fsx_lustre, params) req.send_request() end |
#update_location_fsx_ontap(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Amazon FSx for NetApp ONTAP transfer location that you’re using with DataSync.
For more information, see [Configuring DataSync transfers with FSx for ONTAP].
[1]: docs.aws.amazon.com/datasync/latest/userguide/create-ontap-location.html
4145 4146 4147 4148 |
# File 'lib/aws-sdk-datasync/client.rb', line 4145 def update_location_fsx_ontap(params = {}, = {}) req = build_request(:update_location_fsx_ontap, params) req.send_request() end |
#update_location_fsx_open_zfs(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Amazon FSx for OpenZFS transfer location that you’re using with DataSync.
For more information, see [Configuring DataSync transfers with FSx for OpenZFS].
<note markdown=“1”> Request parameters related to ‘SMB` aren’t supported with the ‘UpdateLocationFsxOpenZfs` operation.
</note>
[1]: docs.aws.amazon.com/datasync/latest/userguide/create-openzfs-location.html
4218 4219 4220 4221 |
# File 'lib/aws-sdk-datasync/client.rb', line 4218 def update_location_fsx_open_zfs(params = {}, = {}) req = build_request(:update_location_fsx_open_zfs, params) req.send_request() end |
#update_location_fsx_windows(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Amazon FSx for Windows File Server transfer location that you’re using with DataSync.
For more information, see [Configuring DataSync transfers with FSx for Windows File Server].
[1]: docs.aws.amazon.com/datasync/latest/userguide/create-fsx-location.html
4304 4305 4306 4307 |
# File 'lib/aws-sdk-datasync/client.rb', line 4304 def update_location_fsx_windows(params = {}, = {}) req = build_request(:update_location_fsx_windows, params) req.send_request() end |
#update_location_hdfs(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Hadoop Distributed File System (HDFS) transfer location that you’re using with DataSync.
For more information, see [Configuring DataSync transfers with an HDFS cluster].
[1]: docs.aws.amazon.com/datasync/latest/userguide/create-hdfs-location.html
4425 4426 4427 4428 |
# File 'lib/aws-sdk-datasync/client.rb', line 4425 def update_location_hdfs(params = {}, = {}) req = build_request(:update_location_hdfs, params) req.send_request() end |
#update_location_nfs(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Network File System (NFS) transfer location that you’re using with DataSync.
For more information, see [Configuring transfers with an NFS file server].
[1]: docs.aws.amazon.com/datasync/latest/userguide/create-nfs-location.html
4487 4488 4489 4490 |
# File 'lib/aws-sdk-datasync/client.rb', line 4487 def update_location_nfs(params = {}, = {}) req = build_request(:update_location_nfs, params) req.send_request() end |
#update_location_object_storage(params = {}) ⇒ Struct
Modifies the following configuration parameters of the object storage transfer location that you’re using with DataSync.
For more information, see [Configuring DataSync transfers with an object storage system].
[1]: docs.aws.amazon.com/datasync/latest/userguide/create-object-location.html
4619 4620 4621 4622 |
# File 'lib/aws-sdk-datasync/client.rb', line 4619 def update_location_object_storage(params = {}, = {}) req = build_request(:update_location_object_storage, params) req.send_request() end |
#update_location_s3(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Amazon S3 transfer location that you’re using with DataSync.
Before you begin, make sure that you read the following topics:
* [Storage class considerations with Amazon S3 locations][1]
- Evaluating S3 request costs when using DataSync][2
[1]: docs.aws.amazon.com/datasync/latest/userguide/create-s3-location.html#using-storage-classes [2]: docs.aws.amazon.com/datasync/latest/userguide/create-s3-location.html#create-s3-location-s3-requests
4703 4704 4705 4706 |
# File 'lib/aws-sdk-datasync/client.rb', line 4703 def update_location_s3(params = {}, = {}) req = build_request(:update_location_s3, params) req.send_request() end |
#update_location_smb(params = {}) ⇒ Struct
Modifies the following configuration parameters of the Server Message Block (SMB) transfer location that you’re using with DataSync.
For more information, see [Configuring DataSync transfers with an SMB file server].
[1]: docs.aws.amazon.com/datasync/latest/userguide/create-smb-location.html
4874 4875 4876 4877 |
# File 'lib/aws-sdk-datasync/client.rb', line 4874 def update_location_smb(params = {}, = {}) req = build_request(:update_location_smb, params) req.send_request() end |
#update_task(params = {}) ⇒ Struct
Updates the configuration of a task, which defines where and how DataSync transfers your data.
5069 5070 5071 5072 |
# File 'lib/aws-sdk-datasync/client.rb', line 5069 def update_task(params = {}, = {}) req = build_request(:update_task, params) req.send_request() end |
#update_task_execution(params = {}) ⇒ Struct
Updates the configuration of a running DataSync task execution.
<note markdown=“1”> Currently, the only ‘Option` that you can modify with `UpdateTaskExecution` is ` BytesPerSecond `, which throttles bandwidth for a running or queued task execution.
</note>
5132 5133 5134 5135 |
# File 'lib/aws-sdk-datasync/client.rb', line 5132 def update_task_execution(params = {}, = {}) req = build_request(:update_task_execution, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5161 5162 5163 |
# File 'lib/aws-sdk-datasync/client.rb', line 5161 def waiter_names [] end |