Method: Aws::DataSync::Types::CreateLocationAzureBlobRequest#agent_arns
- Defined in:
- lib/aws-sdk-datasync/types.rb
#agent_arns ⇒ Array<String>
(Optional) Specifies the Amazon Resource Name (ARN) of the DataSync agent that can connect with your Azure Blob Storage container. If you are setting up an agentless cross-cloud transfer, you do not need to specify a value for this parameter.
You can specify more than one agent. For more information, see [Using multiple agents for your transfer].
<note markdown=“1”> Make sure you configure this parameter correctly when you first create your storage location. You cannot add or remove agents from a storage location after you create it.
</note>
[1]: docs.aws.amazon.com/datasync/latest/userguide/multiple-agents.html
335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/aws-sdk-datasync/types.rb', line 335 class CreateLocationAzureBlobRequest < Struct.new( :container_url, :authentication_type, :sas_configuration, :blob_type, :access_tier, :subdirectory, :agent_arns, :tags, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |