Class: Aws::DataSync::Types::CreateLocationNfsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataSync::Types::CreateLocationNfsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datasync/types.rb
Overview
CreateLocationNfsRequest
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#mount_options ⇒ Types::NfsMountOptions
Specifies the options that DataSync can use to mount your NFS file server.
-
#on_prem_config ⇒ Types::OnPremConfig
Specifies the Amazon Resource Name (ARN) of the DataSync agent that can connect to your NFS file server.
-
#server_hostname ⇒ String
Specifies the DNS name or IP address (IPv4 or IPv6) of the NFS file server that your DataSync agent connects to.
-
#subdirectory ⇒ String
Specifies the export path in your NFS file server that you want DataSync to mount.
-
#tags ⇒ Array<Types::TagListEntry>
Specifies labels that help you categorize, filter, and search for your Amazon Web Services resources.
Instance Attribute Details
#mount_options ⇒ Types::NfsMountOptions
Specifies the options that DataSync can use to mount your NFS file server.
1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/aws-sdk-datasync/types.rb', line 1035 class CreateLocationNfsRequest < Struct.new( :subdirectory, :server_hostname, :on_prem_config, :mount_options, :tags) SENSITIVE = [] include Aws::Structure end |
#on_prem_config ⇒ Types::OnPremConfig
Specifies the Amazon Resource Name (ARN) of the DataSync agent that can connect to your NFS file server.
You can specify more than one agent. For more information, see Using multiple DataSync agents.
1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/aws-sdk-datasync/types.rb', line 1035 class CreateLocationNfsRequest < Struct.new( :subdirectory, :server_hostname, :on_prem_config, :mount_options, :tags) SENSITIVE = [] include Aws::Structure end |
#server_hostname ⇒ String
Specifies the DNS name or IP address (IPv4 or IPv6) of the NFS file server that your DataSync agent connects to.
1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/aws-sdk-datasync/types.rb', line 1035 class CreateLocationNfsRequest < Struct.new( :subdirectory, :server_hostname, :on_prem_config, :mount_options, :tags) SENSITIVE = [] include Aws::Structure end |
#subdirectory ⇒ String
Specifies the export path in your NFS file server that you want DataSync to mount.
This path (or a subdirectory of the path) is where DataSync transfers data to or from. For information on configuring an export for DataSync, see Accessing NFS file servers.
1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/aws-sdk-datasync/types.rb', line 1035 class CreateLocationNfsRequest < Struct.new( :subdirectory, :server_hostname, :on_prem_config, :mount_options, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::TagListEntry>
Specifies labels that help you categorize, filter, and search for your Amazon Web Services resources. We recommend creating at least a name tag for your location.
1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/aws-sdk-datasync/types.rb', line 1035 class CreateLocationNfsRequest < Struct.new( :subdirectory, :server_hostname, :on_prem_config, :mount_options, :tags) SENSITIVE = [] include Aws::Structure end |