Class: Aws::DataSync::Types::DescribeLocationAzureBlobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataSync::Types::DescribeLocationAzureBlobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datasync/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_tier ⇒ String
The access tier that you want your objects or files transferred into.
-
#agent_arns ⇒ Array<String>
The ARNs of the DataSync agents that can connect with your Azure Blob Storage container.
-
#authentication_type ⇒ String
The authentication method DataSync uses to access your Azure Blob Storage.
-
#blob_type ⇒ String
The type of blob that you want your objects or files to be when transferring them into Azure Blob Storage.
-
#cmk_secret_config ⇒ Types::CmkSecretConfig
Describes configuration information for a DataSync-managed secret, such as an authentication token that DataSync uses to access a specific storage location, with a customer-managed KMS key.
-
#creation_time ⇒ Time
The time that your Azure Blob Storage transfer location was created.
-
#custom_secret_config ⇒ Types::CustomSecretConfig
Describes configuration information for a customer-managed secret, such as an authentication token that DataSync uses to access a specific storage location, with a customer-managed Identity and Access Management (IAM) role that provides access to the secret.
-
#location_arn ⇒ String
The ARN of your Azure Blob Storage transfer location.
-
#location_uri ⇒ String
The URL of the Azure Blob Storage container involved in your transfer.
-
#managed_secret_config ⇒ Types::ManagedSecretConfig
Describes configuration information for a DataSync-managed secret, such as an authentication token that DataSync uses to access a specific storage location.
Instance Attribute Details
#access_tier ⇒ String
The access tier that you want your objects or files transferred into. This only applies when using the location as a transfer destination. For more information, see [Access tiers].
1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 |
# File 'lib/aws-sdk-datasync/types.rb', line 1978 class DescribeLocationAzureBlobResponse < Struct.new( :location_arn, :location_uri, :authentication_type, :blob_type, :access_tier, :agent_arns, :creation_time, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#agent_arns ⇒ Array<String>
The ARNs of the DataSync agents that can connect with your Azure Blob Storage container.
1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 |
# File 'lib/aws-sdk-datasync/types.rb', line 1978 class DescribeLocationAzureBlobResponse < Struct.new( :location_arn, :location_uri, :authentication_type, :blob_type, :access_tier, :agent_arns, :creation_time, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#authentication_type ⇒ String
The authentication method DataSync uses to access your Azure Blob Storage. DataSync can access blob storage using a shared access signature (SAS).
1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 |
# File 'lib/aws-sdk-datasync/types.rb', line 1978 class DescribeLocationAzureBlobResponse < Struct.new( :location_arn, :location_uri, :authentication_type, :blob_type, :access_tier, :agent_arns, :creation_time, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#blob_type ⇒ String
The type of blob that you want your objects or files to be when transferring them into Azure Blob Storage. Currently, DataSync only supports moving data into Azure Blob Storage as block blobs. For more information on blob types, see the [Azure Blob Storage documentation].
1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 |
# File 'lib/aws-sdk-datasync/types.rb', line 1978 class DescribeLocationAzureBlobResponse < Struct.new( :location_arn, :location_uri, :authentication_type, :blob_type, :access_tier, :agent_arns, :creation_time, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#cmk_secret_config ⇒ Types::CmkSecretConfig
Describes configuration information for a DataSync-managed secret, such as an authentication token that DataSync uses to access a specific storage location, with a customer-managed KMS key.
1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 |
# File 'lib/aws-sdk-datasync/types.rb', line 1978 class DescribeLocationAzureBlobResponse < Struct.new( :location_arn, :location_uri, :authentication_type, :blob_type, :access_tier, :agent_arns, :creation_time, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time that your Azure Blob Storage transfer location was created.
1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 |
# File 'lib/aws-sdk-datasync/types.rb', line 1978 class DescribeLocationAzureBlobResponse < Struct.new( :location_arn, :location_uri, :authentication_type, :blob_type, :access_tier, :agent_arns, :creation_time, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#custom_secret_config ⇒ Types::CustomSecretConfig
Describes configuration information for a customer-managed secret, such as an authentication token that DataSync uses to access a specific storage location, with a customer-managed Identity and Access Management (IAM) role that provides access to the secret.
1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 |
# File 'lib/aws-sdk-datasync/types.rb', line 1978 class DescribeLocationAzureBlobResponse < Struct.new( :location_arn, :location_uri, :authentication_type, :blob_type, :access_tier, :agent_arns, :creation_time, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#location_arn ⇒ String
The ARN of your Azure Blob Storage transfer location.
1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 |
# File 'lib/aws-sdk-datasync/types.rb', line 1978 class DescribeLocationAzureBlobResponse < Struct.new( :location_arn, :location_uri, :authentication_type, :blob_type, :access_tier, :agent_arns, :creation_time, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#location_uri ⇒ String
The URL of the Azure Blob Storage container involved in your transfer.
1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 |
# File 'lib/aws-sdk-datasync/types.rb', line 1978 class DescribeLocationAzureBlobResponse < Struct.new( :location_arn, :location_uri, :authentication_type, :blob_type, :access_tier, :agent_arns, :creation_time, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#managed_secret_config ⇒ Types::ManagedSecretConfig
Describes configuration information for a DataSync-managed secret, such as an authentication token that DataSync uses to access a specific storage location. DataSync uses the default Amazon Web Services-managed KMS key to encrypt this secret in Secrets Manager.
1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 |
# File 'lib/aws-sdk-datasync/types.rb', line 1978 class DescribeLocationAzureBlobResponse < Struct.new( :location_arn, :location_uri, :authentication_type, :blob_type, :access_tier, :agent_arns, :creation_time, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |