Class: Aws::DataSync::Types::DescribeLocationEfsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datasync/types.rb

Overview

DescribeLocationEfsResponse

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_point_arnString

The ARN of the access point that DataSync uses to access the Amazon EFS file system.

For more information, see [Accessing restricted file systems].

[1]: docs.aws.amazon.com/datasync/latest/userguide/create-efs-location.html#create-efs-location-iam



1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
# File 'lib/aws-sdk-datasync/types.rb', line 1933

class DescribeLocationEfsResponse < Struct.new(
  :location_arn,
  :location_uri,
  :ec2_config,
  :creation_time,
  :access_point_arn,
  :file_system_access_role_arn,
  :in_transit_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The time that the location was created.



1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
# File 'lib/aws-sdk-datasync/types.rb', line 1933

class DescribeLocationEfsResponse < Struct.new(
  :location_arn,
  :location_uri,
  :ec2_config,
  :creation_time,
  :access_point_arn,
  :file_system_access_role_arn,
  :in_transit_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#ec2_configTypes::Ec2Config

The subnet and security groups that DataSync uses to connect to one of your Amazon EFS file system’s [mount targets].

[1]: docs.aws.amazon.com/efs/latest/ug/accessing-fs.html



1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
# File 'lib/aws-sdk-datasync/types.rb', line 1933

class DescribeLocationEfsResponse < Struct.new(
  :location_arn,
  :location_uri,
  :ec2_config,
  :creation_time,
  :access_point_arn,
  :file_system_access_role_arn,
  :in_transit_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#file_system_access_role_arnString

The Identity and Access Management (IAM) role that allows DataSync to access your Amazon EFS file system.

For more information, see [Creating a DataSync IAM role for file system access].

[1]: docs.aws.amazon.com/datasync/latest/userguide/create-efs-location.html#create-efs-location-iam-role



1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
# File 'lib/aws-sdk-datasync/types.rb', line 1933

class DescribeLocationEfsResponse < Struct.new(
  :location_arn,
  :location_uri,
  :ec2_config,
  :creation_time,
  :access_point_arn,
  :file_system_access_role_arn,
  :in_transit_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#in_transit_encryptionString

Indicates whether DataSync uses Transport Layer Security (TLS) encryption when transferring data to or from the Amazon EFS file system.



1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
# File 'lib/aws-sdk-datasync/types.rb', line 1933

class DescribeLocationEfsResponse < Struct.new(
  :location_arn,
  :location_uri,
  :ec2_config,
  :creation_time,
  :access_point_arn,
  :file_system_access_role_arn,
  :in_transit_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#location_arnString

The ARN of the Amazon EFS file system location.



1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
# File 'lib/aws-sdk-datasync/types.rb', line 1933

class DescribeLocationEfsResponse < Struct.new(
  :location_arn,
  :location_uri,
  :ec2_config,
  :creation_time,
  :access_point_arn,
  :file_system_access_role_arn,
  :in_transit_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#location_uriString

The URL of the Amazon EFS file system location.



1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
# File 'lib/aws-sdk-datasync/types.rb', line 1933

class DescribeLocationEfsResponse < Struct.new(
  :location_arn,
  :location_uri,
  :ec2_config,
  :creation_time,
  :access_point_arn,
  :file_system_access_role_arn,
  :in_transit_encryption)
  SENSITIVE = []
  include Aws::Structure
end