Class: Aws::DataSync::Types::DescribeLocationFsxWindowsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataSync::Types::DescribeLocationFsxWindowsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datasync/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cmk_secret_config ⇒ Types::CmkSecretConfig
Describes configuration information for a DataSync-managed secret, such as a
Passwordthat DataSync uses to access a specific storage location, with a customer-managed KMS key. -
#creation_time ⇒ Time
The time that the FSx for Windows File Server location was created.
-
#custom_secret_config ⇒ Types::CustomSecretConfig
Describes configuration information for a customer-managed secret, such as a
Passwordthat DataSync uses to access a specific storage location, with a customer-managed Identity and Access Management (IAM) role that provides access to the secret. -
#domain ⇒ String
The name of the Microsoft Active Directory domain that the FSx for Windows File Server file system belongs to.
-
#location_arn ⇒ String
The ARN of the FSx for Windows File Server location.
-
#location_uri ⇒ String
The uniform resource identifier (URI) of the FSx for Windows File Server location.
-
#managed_secret_config ⇒ Types::ManagedSecretConfig
Describes configuration information for a DataSync-managed secret, such as a
Passwordthat DataSync uses to access a specific storage location. -
#security_group_arns ⇒ Array<String>
The ARNs of the Amazon EC2 security groups that provide access to your file system’s preferred subnet.
-
#user ⇒ String
The user with the permissions to mount and access the FSx for Windows File Server file system.
Instance Attribute Details
#cmk_secret_config ⇒ Types::CmkSecretConfig
Describes configuration information for a DataSync-managed secret, such as a Password that DataSync uses to access a specific storage location, with a customer-managed KMS key.
2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 |
# File 'lib/aws-sdk-datasync/types.rb', line 2295 class DescribeLocationFsxWindowsResponse < Struct.new( :location_arn, :location_uri, :security_group_arns, :creation_time, :user, :domain, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time that the FSx for Windows File Server location was created.
2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 |
# File 'lib/aws-sdk-datasync/types.rb', line 2295 class DescribeLocationFsxWindowsResponse < Struct.new( :location_arn, :location_uri, :security_group_arns, :creation_time, :user, :domain, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#custom_secret_config ⇒ Types::CustomSecretConfig
Describes configuration information for a customer-managed secret, such as a Password that DataSync uses to access a specific storage location, with a customer-managed Identity and Access Management (IAM) role that provides access to the secret.
2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 |
# File 'lib/aws-sdk-datasync/types.rb', line 2295 class DescribeLocationFsxWindowsResponse < Struct.new( :location_arn, :location_uri, :security_group_arns, :creation_time, :user, :domain, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#domain ⇒ String
The name of the Microsoft Active Directory domain that the FSx for Windows File Server file system belongs to.
2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 |
# File 'lib/aws-sdk-datasync/types.rb', line 2295 class DescribeLocationFsxWindowsResponse < Struct.new( :location_arn, :location_uri, :security_group_arns, :creation_time, :user, :domain, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#location_arn ⇒ String
The ARN of the FSx for Windows File Server location.
2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 |
# File 'lib/aws-sdk-datasync/types.rb', line 2295 class DescribeLocationFsxWindowsResponse < Struct.new( :location_arn, :location_uri, :security_group_arns, :creation_time, :user, :domain, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#location_uri ⇒ String
The uniform resource identifier (URI) of the FSx for Windows File Server location.
2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 |
# File 'lib/aws-sdk-datasync/types.rb', line 2295 class DescribeLocationFsxWindowsResponse < Struct.new( :location_arn, :location_uri, :security_group_arns, :creation_time, :user, :domain, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#managed_secret_config ⇒ Types::ManagedSecretConfig
Describes configuration information for a DataSync-managed secret, such as a Password that DataSync uses to access a specific storage location. DataSync uses the default Amazon Web Services-managed KMS key to encrypt this secret in Secrets Manager.
2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 |
# File 'lib/aws-sdk-datasync/types.rb', line 2295 class DescribeLocationFsxWindowsResponse < Struct.new( :location_arn, :location_uri, :security_group_arns, :creation_time, :user, :domain, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#security_group_arns ⇒ Array<String>
The ARNs of the Amazon EC2 security groups that provide access to your file system’s preferred subnet.
For information about configuring security groups for file system access, see the [ *Amazon FSx for Windows File Server User Guide* ][1].
[1]: docs.aws.amazon.com/fsx/latest/WindowsGuide/limit-access-security-groups.html
2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 |
# File 'lib/aws-sdk-datasync/types.rb', line 2295 class DescribeLocationFsxWindowsResponse < Struct.new( :location_arn, :location_uri, :security_group_arns, :creation_time, :user, :domain, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#user ⇒ String
The user with the permissions to mount and access the FSx for Windows File Server file system.
2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 |
# File 'lib/aws-sdk-datasync/types.rb', line 2295 class DescribeLocationFsxWindowsResponse < Struct.new( :location_arn, :location_uri, :security_group_arns, :creation_time, :user, :domain, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |