Class: Aws::DataSync::Types::FsxProtocolSmb
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataSync::Types::FsxProtocolSmb
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datasync/types.rb
Overview
Specifies the Server Message Block (SMB) protocol configuration that DataSync uses to access your Amazon FSx for NetApp ONTAP file system’s storage virtual machine (SVM). For more information, see [Providing DataSync access to FSx for ONTAP file systems].
Constant Summary collapse
- SENSITIVE =
[:password]
Instance Attribute Summary collapse
-
#cmk_secret_config ⇒ Types::CmkSecretConfig
Specifies configuration information for a DataSync-managed secret, which includes the password that DataSync uses to access a specific FSx for ONTAP storage location (using SMB), with a customer-managed KMS key.
-
#custom_secret_config ⇒ Types::CustomSecretConfig
Specifies configuration information for a customer-managed Secrets Manager secret where the password for an FSx for ONTAP storage location (using SMB) is stored in plain text, in Secrets Manager.
-
#domain ⇒ String
Specifies the name of the Windows domain that your storage virtual machine (SVM) belongs to.
-
#managed_secret_config ⇒ Types::ManagedSecretConfig
Describes configuration information for a DataSync-managed secret, such as a
Passwordthat DataSync uses to access a specific storage location. -
#mount_options ⇒ Types::SmbMountOptions
Specifies the version of the Server Message Block (SMB) protocol that DataSync uses to access an SMB file server.
-
#password ⇒ String
Specifies the password of a user who has permission to access your SVM.
-
#user ⇒ String
Specifies a user that can mount and access the files, folders, and metadata in your SVM.
Instance Attribute Details
#cmk_secret_config ⇒ Types::CmkSecretConfig
Specifies configuration information for a DataSync-managed secret, which includes the password that DataSync uses to access a specific FSx for ONTAP storage location (using SMB), with a customer-managed KMS key.
When you include this parameter as part of a CreateLocationFsxOntap request, you provide only the KMS key ARN. DataSync uses this KMS key together with the Password you specify for to create a DataSync-managed secret to store the location access credentials.
Make sure that DataSync has permission to access the KMS key that you specify. For more information, see [ Using a service-managed secret encrypted with a custom KMS key].
<note markdown=“1”> You can use either CmkSecretConfig (with Password) or CustomSecretConfig (without Password) to provide credentials for a CreateLocationFsxOntap request. Do not provide both parameters for the same request.
</note>
[1]: docs.aws.amazon.com/datasync/latest/userguide/location-credentials.html#service-secret-custom-key
3701 3702 3703 3704 3705 3706 3707 3708 3709 3710 3711 |
# File 'lib/aws-sdk-datasync/types.rb', line 3701 class FsxProtocolSmb < Struct.new( :domain, :mount_options, :password, :user, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:password] include Aws::Structure end |
#custom_secret_config ⇒ Types::CustomSecretConfig
Specifies configuration information for a customer-managed Secrets Manager secret where the password for an FSx for ONTAP storage location (using SMB) is stored in plain text, in Secrets Manager. This configuration includes the secret ARN, and the ARN for an IAM role that provides access to the secret. For more information, see [ Using a secret that you manage].
<note markdown=“1”> You can use either CmkSecretConfig (with Password) or CustomSecretConfig (without Password) to provide credentials for a CreateLocationFsxOntap request. Do not provide both parameters for the same request.
</note>
[1]: docs.aws.amazon.com/datasync/latest/userguide/location-credentials.html#custom-secret-custom-key
3701 3702 3703 3704 3705 3706 3707 3708 3709 3710 3711 |
# File 'lib/aws-sdk-datasync/types.rb', line 3701 class FsxProtocolSmb < Struct.new( :domain, :mount_options, :password, :user, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:password] include Aws::Structure end |
#domain ⇒ String
Specifies the name of the Windows domain that your storage virtual machine (SVM) belongs to.
If you have multiple domains in your environment, configuring this setting makes sure that DataSync connects to the right SVM.
If you have multiple Active Directory domains in your environment, configuring this parameter makes sure that DataSync connects to the right SVM.
3701 3702 3703 3704 3705 3706 3707 3708 3709 3710 3711 |
# File 'lib/aws-sdk-datasync/types.rb', line 3701 class FsxProtocolSmb < Struct.new( :domain, :mount_options, :password, :user, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:password] include Aws::Structure end |
#managed_secret_config ⇒ Types::ManagedSecretConfig
Describes configuration information for a DataSync-managed secret, such as a Password that DataSync uses to access a specific storage location. DataSync uses the default Amazon Web Services-managed KMS key to encrypt this secret in Secrets Manager.
<note markdown=“1”> Do not provide this for a CreateLocation request. ManagedSecretConfig is a ReadOnly property and is only be populated in the DescribeLocation response.
</note>
3701 3702 3703 3704 3705 3706 3707 3708 3709 3710 3711 |
# File 'lib/aws-sdk-datasync/types.rb', line 3701 class FsxProtocolSmb < Struct.new( :domain, :mount_options, :password, :user, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:password] include Aws::Structure end |
#mount_options ⇒ Types::SmbMountOptions
Specifies the version of the Server Message Block (SMB) protocol that DataSync uses to access an SMB file server.
3701 3702 3703 3704 3705 3706 3707 3708 3709 3710 3711 |
# File 'lib/aws-sdk-datasync/types.rb', line 3701 class FsxProtocolSmb < Struct.new( :domain, :mount_options, :password, :user, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:password] include Aws::Structure end |
#password ⇒ String
Specifies the password of a user who has permission to access your SVM.
3701 3702 3703 3704 3705 3706 3707 3708 3709 3710 3711 |
# File 'lib/aws-sdk-datasync/types.rb', line 3701 class FsxProtocolSmb < Struct.new( :domain, :mount_options, :password, :user, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:password] include Aws::Structure end |
#user ⇒ String
Specifies a user that can mount and access the files, folders, and metadata in your SVM.
For information about choosing a user with the right level of access for your transfer, see [Using the SMB protocol].
[1]: docs.aws.amazon.com/datasync/latest/userguide/create-ontap-location.html#create-ontap-location-smb
3701 3702 3703 3704 3705 3706 3707 3708 3709 3710 3711 |
# File 'lib/aws-sdk-datasync/types.rb', line 3701 class FsxProtocolSmb < Struct.new( :domain, :mount_options, :password, :user, :managed_secret_config, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:password] include Aws::Structure end |