Class: Aws::DataSync::Types::ListTasksRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataSync::Types::ListTasksRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datasync/types.rb
Overview
ListTasksRequest
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::TaskFilter>
You can use API filters to narrow down the list of resources returned by
ListTasks. -
#max_results ⇒ Integer
The maximum number of tasks to return.
-
#next_token ⇒ String
An opaque string that indicates the position at which to begin the next list of tasks.
Instance Attribute Details
#filters ⇒ Array<Types::TaskFilter>
You can use API filters to narrow down the list of resources returned by ListTasks. For example, to retrieve all tasks on a specific source location, you can use ListTasks with filter name LocationId and ‘Operator Equals` with the ARN for the location.
4077 4078 4079 4080 4081 4082 4083 |
# File 'lib/aws-sdk-datasync/types.rb', line 4077 class ListTasksRequest < Struct.new( :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of tasks to return.
4077 4078 4079 4080 4081 4082 4083 |
# File 'lib/aws-sdk-datasync/types.rb', line 4077 class ListTasksRequest < Struct.new( :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An opaque string that indicates the position at which to begin the next list of tasks.
4077 4078 4079 4080 4081 4082 4083 |
# File 'lib/aws-sdk-datasync/types.rb', line 4077 class ListTasksRequest < Struct.new( :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |