Class: Aws::DataSync::Types::ReportOverrides

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datasync/types.rb

Overview

The level of detail included in each aspect of your DataSync task report.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deletedTypes::ReportOverride

Specifies the level of reporting for the files, objects, and directories that DataSync attempted to delete in your destination location. This only applies if you configure your task to delete data in the destination that isn't in the source.



4892
4893
4894
4895
4896
4897
4898
4899
# File 'lib/aws-sdk-datasync/types.rb', line 4892

class ReportOverrides < Struct.new(
  :transferred,
  :verified,
  :deleted,
  :skipped)
  SENSITIVE = []
  include Aws::Structure
end

#skippedTypes::ReportOverride

Specifies the level of reporting for the files, objects, and directories that DataSync attempted to skip during your transfer.



4892
4893
4894
4895
4896
4897
4898
4899
# File 'lib/aws-sdk-datasync/types.rb', line 4892

class ReportOverrides < Struct.new(
  :transferred,
  :verified,
  :deleted,
  :skipped)
  SENSITIVE = []
  include Aws::Structure
end

#transferredTypes::ReportOverride

Specifies the level of reporting for the files, objects, and directories that DataSync attempted to transfer.



4892
4893
4894
4895
4896
4897
4898
4899
# File 'lib/aws-sdk-datasync/types.rb', line 4892

class ReportOverrides < Struct.new(
  :transferred,
  :verified,
  :deleted,
  :skipped)
  SENSITIVE = []
  include Aws::Structure
end

#verifiedTypes::ReportOverride

Specifies the level of reporting for the files, objects, and directories that DataSync attempted to verify at the end of your transfer.



4892
4893
4894
4895
4896
4897
4898
4899
# File 'lib/aws-sdk-datasync/types.rb', line 4892

class ReportOverrides < Struct.new(
  :transferred,
  :verified,
  :deleted,
  :skipped)
  SENSITIVE = []
  include Aws::Structure
end