Class: Aws::DataSync::Types::UpdateLocationFsxWindowsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataSync::Types::UpdateLocationFsxWindowsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datasync/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:password]
Instance Attribute Summary collapse
-
#cmk_secret_config ⇒ Types::CmkSecretConfig
Specifies configuration information for a DataSync-managed secret, such as a
Passwordor set of credentials that DataSync uses to access a specific transfer location, and a customer-managed KMS key. -
#custom_secret_config ⇒ Types::CustomSecretConfig
Specifies configuration information for a customer-managed secret, such as a
Passwordor set of credentials that DataSync uses to access a specific transfer location, and a customer-managed Identity and Access Management (IAM) role that provides access to the secret. -
#domain ⇒ String
Specifies the name of the Windows domain that your FSx for Windows File Server file system belongs to.
-
#location_arn ⇒ String
Specifies the ARN of the FSx for Windows File Server transfer location that you’re updating.
-
#password ⇒ String
Specifies the password of the user with the permissions to mount and access the files, folders, and file metadata in your FSx for Windows File Server file system.
-
#subdirectory ⇒ String
Specifies a mount path for your file system using forward slashes.
-
#user ⇒ String
Specifies the user with the permissions to mount and access the files, folders, and file metadata in your FSx for Windows File Server file system.
Instance Attribute Details
#cmk_secret_config ⇒ Types::CmkSecretConfig
Specifies configuration information for a DataSync-managed secret, such as a Password or set of credentials that DataSync uses to access a specific transfer location, and a customer-managed KMS key.
6184 6185 6186 6187 6188 6189 6190 6191 6192 6193 6194 |
# File 'lib/aws-sdk-datasync/types.rb', line 6184 class UpdateLocationFsxWindowsRequest < Struct.new( :location_arn, :subdirectory, :domain, :user, :password, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:password] include Aws::Structure end |
#custom_secret_config ⇒ Types::CustomSecretConfig
Specifies configuration information for a customer-managed secret, such as a Password or set of credentials that DataSync uses to access a specific transfer location, and a customer-managed Identity and Access Management (IAM) role that provides access to the secret.
6184 6185 6186 6187 6188 6189 6190 6191 6192 6193 6194 |
# File 'lib/aws-sdk-datasync/types.rb', line 6184 class UpdateLocationFsxWindowsRequest < Struct.new( :location_arn, :subdirectory, :domain, :user, :password, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:password] include Aws::Structure end |
#domain ⇒ String
Specifies the name of the Windows domain that your FSx for Windows File Server file system belongs to.
If you have multiple Active Directory domains in your environment, configuring this parameter makes sure that DataSync connects to the right file system.
6184 6185 6186 6187 6188 6189 6190 6191 6192 6193 6194 |
# File 'lib/aws-sdk-datasync/types.rb', line 6184 class UpdateLocationFsxWindowsRequest < Struct.new( :location_arn, :subdirectory, :domain, :user, :password, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:password] include Aws::Structure end |
#location_arn ⇒ String
Specifies the ARN of the FSx for Windows File Server transfer location that you’re updating.
6184 6185 6186 6187 6188 6189 6190 6191 6192 6193 6194 |
# File 'lib/aws-sdk-datasync/types.rb', line 6184 class UpdateLocationFsxWindowsRequest < Struct.new( :location_arn, :subdirectory, :domain, :user, :password, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:password] include Aws::Structure end |
#password ⇒ String
Specifies the password of the user with the permissions to mount and access the files, folders, and file metadata in your FSx for Windows File Server file system.
6184 6185 6186 6187 6188 6189 6190 6191 6192 6193 6194 |
# File 'lib/aws-sdk-datasync/types.rb', line 6184 class UpdateLocationFsxWindowsRequest < Struct.new( :location_arn, :subdirectory, :domain, :user, :password, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:password] include Aws::Structure end |
#subdirectory ⇒ String
Specifies a mount path for your file system using forward slashes. DataSync uses this subdirectory to read or write data (depending on whether the file system is a source or destination location).
6184 6185 6186 6187 6188 6189 6190 6191 6192 6193 6194 |
# File 'lib/aws-sdk-datasync/types.rb', line 6184 class UpdateLocationFsxWindowsRequest < Struct.new( :location_arn, :subdirectory, :domain, :user, :password, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:password] include Aws::Structure end |
#user ⇒ String
Specifies the user with the permissions to mount and access the files, folders, and file metadata in your FSx for Windows File Server file system.
For information about choosing a user with the right level of access for your transfer, see [required permissions] for FSx for Windows File Server locations.
6184 6185 6186 6187 6188 6189 6190 6191 6192 6193 6194 |
# File 'lib/aws-sdk-datasync/types.rb', line 6184 class UpdateLocationFsxWindowsRequest < Struct.new( :location_arn, :subdirectory, :domain, :user, :password, :cmk_secret_config, :custom_secret_config) SENSITIVE = [:password] include Aws::Structure end |