Class: Aws::DataSync::Types::UpdateLocationHdfsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataSync::Types::UpdateLocationHdfsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datasync/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the DataSync agents that can connect to your HDFS cluster.
-
#authentication_type ⇒ String
The type of authentication used to determine the identity of the user.
-
#block_size ⇒ Integer
The size of the data blocks to write into the HDFS cluster.
-
#cmk_secret_config ⇒ Types::CmkSecretConfig
Specifies configuration information for a DataSync-managed secret, such as a
KerberosKeytabor set of credentials that DataSync uses to access a specific transfer location, and a customer-managed KMS key. -
#custom_secret_config ⇒ Types::CustomSecretConfig
Specifies configuration information for a customer-managed secret, such as a
KerberosKeytabor set of credentials that DataSync uses to access a specific transfer location, and a customer-managed Identity and Access Management (IAM) role that provides access to the secret. -
#kerberos_keytab ⇒ String
The Kerberos key table (keytab) that contains mappings between the defined Kerberos principal and the encrypted keys.
-
#kerberos_krb_5_conf ⇒ String
The
krb5.conffile that contains the Kerberos configuration information. -
#kerberos_principal ⇒ String
The Kerberos principal with access to the files and folders on the HDFS cluster.
-
#kms_key_provider_uri ⇒ String
The URI of the HDFS cluster’s Key Management Server (KMS).
-
#location_arn ⇒ String
The Amazon Resource Name (ARN) of the source HDFS cluster location.
-
#name_nodes ⇒ Array<Types::HdfsNameNode>
The NameNode that manages the HDFS namespace.
-
#qop_configuration ⇒ Types::QopConfiguration
The Quality of Protection (QOP) configuration specifies the Remote Procedure Call (RPC) and data transfer privacy settings configured on the Hadoop Distributed File System (HDFS) cluster.
-
#replication_factor ⇒ Integer
The number of DataNodes to replicate the data to when writing to the HDFS cluster.
-
#simple_user ⇒ String
The user name used to identify the client on the host operating system.
-
#subdirectory ⇒ String
A subdirectory in the HDFS cluster.
Instance Attribute Details
#agent_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the DataSync agents that can connect to your HDFS cluster.
6285 6286 6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 6303 |
# File 'lib/aws-sdk-datasync/types.rb', line 6285 class UpdateLocationHdfsRequest < Struct.new( :location_arn, :subdirectory, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf, :agent_arns, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#authentication_type ⇒ String
The type of authentication used to determine the identity of the user.
6285 6286 6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 6303 |
# File 'lib/aws-sdk-datasync/types.rb', line 6285 class UpdateLocationHdfsRequest < Struct.new( :location_arn, :subdirectory, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf, :agent_arns, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#block_size ⇒ Integer
The size of the data blocks to write into the HDFS cluster.
6285 6286 6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 6303 |
# File 'lib/aws-sdk-datasync/types.rb', line 6285 class UpdateLocationHdfsRequest < Struct.new( :location_arn, :subdirectory, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf, :agent_arns, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#cmk_secret_config ⇒ Types::CmkSecretConfig
Specifies configuration information for a DataSync-managed secret, such as a KerberosKeytab or set of credentials that DataSync uses to access a specific transfer location, and a customer-managed KMS key.
6285 6286 6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 6303 |
# File 'lib/aws-sdk-datasync/types.rb', line 6285 class UpdateLocationHdfsRequest < Struct.new( :location_arn, :subdirectory, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf, :agent_arns, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#custom_secret_config ⇒ Types::CustomSecretConfig
Specifies configuration information for a customer-managed secret, such as a KerberosKeytab or set of credentials that DataSync uses to access a specific transfer location, and a customer-managed Identity and Access Management (IAM) role that provides access to the secret.
6285 6286 6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 6303 |
# File 'lib/aws-sdk-datasync/types.rb', line 6285 class UpdateLocationHdfsRequest < Struct.new( :location_arn, :subdirectory, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf, :agent_arns, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#kerberos_keytab ⇒ String
The Kerberos key table (keytab) that contains mappings between the defined Kerberos principal and the encrypted keys. You can load the keytab from a file by providing the file’s address.
6285 6286 6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 6303 |
# File 'lib/aws-sdk-datasync/types.rb', line 6285 class UpdateLocationHdfsRequest < Struct.new( :location_arn, :subdirectory, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf, :agent_arns, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#kerberos_krb_5_conf ⇒ String
The krb5.conf file that contains the Kerberos configuration information. You can load the krb5.conf file by providing the file’s address. If you’re using the CLI, it performs the base64 encoding for you. Otherwise, provide the base64-encoded text.
6285 6286 6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 6303 |
# File 'lib/aws-sdk-datasync/types.rb', line 6285 class UpdateLocationHdfsRequest < Struct.new( :location_arn, :subdirectory, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf, :agent_arns, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#kerberos_principal ⇒ String
The Kerberos principal with access to the files and folders on the HDFS cluster.
6285 6286 6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 6303 |
# File 'lib/aws-sdk-datasync/types.rb', line 6285 class UpdateLocationHdfsRequest < Struct.new( :location_arn, :subdirectory, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf, :agent_arns, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#kms_key_provider_uri ⇒ String
The URI of the HDFS cluster’s Key Management Server (KMS).
6285 6286 6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 6303 |
# File 'lib/aws-sdk-datasync/types.rb', line 6285 class UpdateLocationHdfsRequest < Struct.new( :location_arn, :subdirectory, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf, :agent_arns, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#location_arn ⇒ String
The Amazon Resource Name (ARN) of the source HDFS cluster location.
6285 6286 6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 6303 |
# File 'lib/aws-sdk-datasync/types.rb', line 6285 class UpdateLocationHdfsRequest < Struct.new( :location_arn, :subdirectory, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf, :agent_arns, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#name_nodes ⇒ Array<Types::HdfsNameNode>
The NameNode that manages the HDFS namespace. The NameNode performs operations such as opening, closing, and renaming files and directories. The NameNode contains the information to map blocks of data to the DataNodes. You can use only one NameNode.
6285 6286 6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 6303 |
# File 'lib/aws-sdk-datasync/types.rb', line 6285 class UpdateLocationHdfsRequest < Struct.new( :location_arn, :subdirectory, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf, :agent_arns, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#qop_configuration ⇒ Types::QopConfiguration
The Quality of Protection (QOP) configuration specifies the Remote Procedure Call (RPC) and data transfer privacy settings configured on the Hadoop Distributed File System (HDFS) cluster.
6285 6286 6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 6303 |
# File 'lib/aws-sdk-datasync/types.rb', line 6285 class UpdateLocationHdfsRequest < Struct.new( :location_arn, :subdirectory, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf, :agent_arns, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#replication_factor ⇒ Integer
The number of DataNodes to replicate the data to when writing to the HDFS cluster.
6285 6286 6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 6303 |
# File 'lib/aws-sdk-datasync/types.rb', line 6285 class UpdateLocationHdfsRequest < Struct.new( :location_arn, :subdirectory, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf, :agent_arns, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#simple_user ⇒ String
The user name used to identify the client on the host operating system.
6285 6286 6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 6303 |
# File 'lib/aws-sdk-datasync/types.rb', line 6285 class UpdateLocationHdfsRequest < Struct.new( :location_arn, :subdirectory, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf, :agent_arns, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |
#subdirectory ⇒ String
A subdirectory in the HDFS cluster. This subdirectory is used to read data from or write data to the HDFS cluster.
6285 6286 6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 6303 |
# File 'lib/aws-sdk-datasync/types.rb', line 6285 class UpdateLocationHdfsRequest < Struct.new( :location_arn, :subdirectory, :name_nodes, :block_size, :replication_factor, :kms_key_provider_uri, :qop_configuration, :authentication_type, :simple_user, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf, :agent_arns, :cmk_secret_config, :custom_secret_config) SENSITIVE = [] include Aws::Structure end |