Class: Aws::DataSync::Types::UpdateLocationSmbRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataSync::Types::UpdateLocationSmbRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datasync/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:password]
Instance Attribute Summary collapse
-
#agent_arns ⇒ Array<String>
Specifies the DataSync agent (or agents) that can connect to your SMB file server.
-
#authentication_type ⇒ String
Specifies the authentication protocol that DataSync uses to connect to your SMB file server.
-
#cmk_secret_config ⇒ Types::CmkSecretConfig
Specifies configuration information for a DataSync-managed secret, such as a
PasswordorKerberosKeytabor set of credentials that DataSync uses to access a specific transfer location, and a customer-managed KMS key. -
#custom_secret_config ⇒ Types::CustomSecretConfig
Specifies configuration information for a customer-managed secret, such as a
PasswordorKerberosKeytabor set of credentials that DataSync uses to access a specific transfer location, and a customer-managed Identity and Access Management (IAM) role that provides access to the secret. -
#dns_ip_addresses ⇒ Array<String>
Specifies the IP addresses (IPv4 or IPv6) for the DNS servers that your SMB file server belongs to.
-
#domain ⇒ String
Specifies the Windows domain name that your SMB file server belongs to.
-
#kerberos_keytab ⇒ String
Specifies your Kerberos key table (keytab) file, which includes mappings between your Kerberos principal and encryption keys.
-
#kerberos_krb_5_conf ⇒ String
Specifies a Kerberos configuration file (
krb5.conf) that defines your Kerberos realm configuration. -
#kerberos_principal ⇒ String
Specifies a Kerberos prinicpal, which is an identity in your Kerberos realm that has permission to access the files, folders, and file metadata in your SMB file server.
-
#location_arn ⇒ String
Specifies the ARN of the SMB location that you want to update.
-
#mount_options ⇒ Types::SmbMountOptions
Specifies the version of the Server Message Block (SMB) protocol that DataSync uses to access an SMB file server.
-
#password ⇒ String
Specifies the password of the user who can mount your SMB file server and has permission to access the files and folders involved in your transfer.
-
#server_hostname ⇒ String
Specifies the domain name or IP address (IPv4 or IPv6) of the SMB file server that your DataSync agent connects to.
-
#subdirectory ⇒ String
Specifies the name of the share exported by your SMB file server where DataSync will read or write data.
-
#user ⇒ String
Specifies the user name that can mount your SMB file server and has permission to access the files and folders involved in your transfer.
Instance Attribute Details
#agent_arns ⇒ Array<String>
Specifies the DataSync agent (or agents) that can connect to your SMB file server. You specify an agent by using its Amazon Resource Name (ARN).
6714 6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 |
# File 'lib/aws-sdk-datasync/types.rb', line 6714 class UpdateLocationSmbRequest < Struct.new( :location_arn, :subdirectory, :server_hostname, :user, :domain, :password, :cmk_secret_config, :custom_secret_config, :agent_arns, :mount_options, :authentication_type, :dns_ip_addresses, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf) SENSITIVE = [:password] include Aws::Structure end |
#authentication_type ⇒ String
Specifies the authentication protocol that DataSync uses to connect
to your SMB file server. DataSync supports NTLM (default) and
KERBEROS authentication.
For more information, see Providing DataSync access to SMB file servers.
6714 6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 |
# File 'lib/aws-sdk-datasync/types.rb', line 6714 class UpdateLocationSmbRequest < Struct.new( :location_arn, :subdirectory, :server_hostname, :user, :domain, :password, :cmk_secret_config, :custom_secret_config, :agent_arns, :mount_options, :authentication_type, :dns_ip_addresses, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf) SENSITIVE = [:password] include Aws::Structure end |
#cmk_secret_config ⇒ Types::CmkSecretConfig
Specifies configuration information for a DataSync-managed secret,
such as a Password or KerberosKeytab or set of credentials that
DataSync uses to access a specific transfer location, and a
customer-managed KMS key.
6714 6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 |
# File 'lib/aws-sdk-datasync/types.rb', line 6714 class UpdateLocationSmbRequest < Struct.new( :location_arn, :subdirectory, :server_hostname, :user, :domain, :password, :cmk_secret_config, :custom_secret_config, :agent_arns, :mount_options, :authentication_type, :dns_ip_addresses, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf) SENSITIVE = [:password] include Aws::Structure end |
#custom_secret_config ⇒ Types::CustomSecretConfig
Specifies configuration information for a customer-managed secret,
such as a Password or KerberosKeytab or set of credentials that
DataSync uses to access a specific transfer location, and a
customer-managed Identity and Access Management (IAM) role that
provides access to the secret.
6714 6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 |
# File 'lib/aws-sdk-datasync/types.rb', line 6714 class UpdateLocationSmbRequest < Struct.new( :location_arn, :subdirectory, :server_hostname, :user, :domain, :password, :cmk_secret_config, :custom_secret_config, :agent_arns, :mount_options, :authentication_type, :dns_ip_addresses, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf) SENSITIVE = [:password] include Aws::Structure end |
#dns_ip_addresses ⇒ Array<String>
Specifies the IP addresses (IPv4 or IPv6) for the DNS servers that
your SMB file server belongs to. This parameter applies only if
AuthenticationType is set to KERBEROS.
If you have multiple domains in your environment, configuring this parameter makes sure that DataSync connects to the right SMB file server.
6714 6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 |
# File 'lib/aws-sdk-datasync/types.rb', line 6714 class UpdateLocationSmbRequest < Struct.new( :location_arn, :subdirectory, :server_hostname, :user, :domain, :password, :cmk_secret_config, :custom_secret_config, :agent_arns, :mount_options, :authentication_type, :dns_ip_addresses, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf) SENSITIVE = [:password] include Aws::Structure end |
#domain ⇒ String
Specifies the Windows domain name that your SMB file server belongs
to. This parameter applies only if AuthenticationType is set to
NTLM.
If you have multiple domains in your environment, configuring this parameter makes sure that DataSync connects to the right file server.
6714 6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 |
# File 'lib/aws-sdk-datasync/types.rb', line 6714 class UpdateLocationSmbRequest < Struct.new( :location_arn, :subdirectory, :server_hostname, :user, :domain, :password, :cmk_secret_config, :custom_secret_config, :agent_arns, :mount_options, :authentication_type, :dns_ip_addresses, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf) SENSITIVE = [:password] include Aws::Structure end |
#kerberos_keytab ⇒ String
Specifies your Kerberos key table (keytab) file, which includes mappings between your Kerberos principal and encryption keys.
To avoid task execution errors, make sure that the Kerberos
principal that you use to create the keytab file matches exactly
what you specify for KerberosPrincipal.
6714 6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 |
# File 'lib/aws-sdk-datasync/types.rb', line 6714 class UpdateLocationSmbRequest < Struct.new( :location_arn, :subdirectory, :server_hostname, :user, :domain, :password, :cmk_secret_config, :custom_secret_config, :agent_arns, :mount_options, :authentication_type, :dns_ip_addresses, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf) SENSITIVE = [:password] include Aws::Structure end |
#kerberos_krb_5_conf ⇒ String
Specifies a Kerberos configuration file (krb5.conf) that defines
your Kerberos realm configuration.
The file must be base64 encoded. If you're using the CLI, the encoding is done for you.
6714 6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 |
# File 'lib/aws-sdk-datasync/types.rb', line 6714 class UpdateLocationSmbRequest < Struct.new( :location_arn, :subdirectory, :server_hostname, :user, :domain, :password, :cmk_secret_config, :custom_secret_config, :agent_arns, :mount_options, :authentication_type, :dns_ip_addresses, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf) SENSITIVE = [:password] include Aws::Structure end |
#kerberos_principal ⇒ String
Specifies a Kerberos prinicpal, which is an identity in your Kerberos realm that has permission to access the files, folders, and file metadata in your SMB file server.
A Kerberos principal might look like
HOST/kerberosuser@MYDOMAIN.ORG.
Principal names are case sensitive. Your DataSync task execution will fail if the principal that you specify for this parameter doesn’t exactly match the principal that you use to create the keytab file.
6714 6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 |
# File 'lib/aws-sdk-datasync/types.rb', line 6714 class UpdateLocationSmbRequest < Struct.new( :location_arn, :subdirectory, :server_hostname, :user, :domain, :password, :cmk_secret_config, :custom_secret_config, :agent_arns, :mount_options, :authentication_type, :dns_ip_addresses, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf) SENSITIVE = [:password] include Aws::Structure end |
#location_arn ⇒ String
Specifies the ARN of the SMB location that you want to update.
6714 6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 |
# File 'lib/aws-sdk-datasync/types.rb', line 6714 class UpdateLocationSmbRequest < Struct.new( :location_arn, :subdirectory, :server_hostname, :user, :domain, :password, :cmk_secret_config, :custom_secret_config, :agent_arns, :mount_options, :authentication_type, :dns_ip_addresses, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf) SENSITIVE = [:password] include Aws::Structure end |
#mount_options ⇒ Types::SmbMountOptions
Specifies the version of the Server Message Block (SMB) protocol that DataSync uses to access an SMB file server.
6714 6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 |
# File 'lib/aws-sdk-datasync/types.rb', line 6714 class UpdateLocationSmbRequest < Struct.new( :location_arn, :subdirectory, :server_hostname, :user, :domain, :password, :cmk_secret_config, :custom_secret_config, :agent_arns, :mount_options, :authentication_type, :dns_ip_addresses, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf) SENSITIVE = [:password] include Aws::Structure end |
#password ⇒ String
Specifies the password of the user who can mount your SMB file
server and has permission to access the files and folders involved
in your transfer. This parameter applies only if
AuthenticationType is set to NTLM.
6714 6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 |
# File 'lib/aws-sdk-datasync/types.rb', line 6714 class UpdateLocationSmbRequest < Struct.new( :location_arn, :subdirectory, :server_hostname, :user, :domain, :password, :cmk_secret_config, :custom_secret_config, :agent_arns, :mount_options, :authentication_type, :dns_ip_addresses, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf) SENSITIVE = [:password] include Aws::Structure end |
#server_hostname ⇒ String
Specifies the domain name or IP address (IPv4 or IPv6) of the SMB file server that your DataSync agent connects to.
6714 6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 |
# File 'lib/aws-sdk-datasync/types.rb', line 6714 class UpdateLocationSmbRequest < Struct.new( :location_arn, :subdirectory, :server_hostname, :user, :domain, :password, :cmk_secret_config, :custom_secret_config, :agent_arns, :mount_options, :authentication_type, :dns_ip_addresses, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf) SENSITIVE = [:password] include Aws::Structure end |
#subdirectory ⇒ String
Specifies the name of the share exported by your SMB file server
where DataSync will read or write data. You can include a
subdirectory in the share path (for example,
/path/to/subdirectory). Make sure that other SMB clients in your
network can also mount this path.
To copy all data in the specified subdirectory, DataSync must be able to mount the SMB share and access all of its data. For more information, see Providing DataSync access to SMB file servers.
6714 6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 |
# File 'lib/aws-sdk-datasync/types.rb', line 6714 class UpdateLocationSmbRequest < Struct.new( :location_arn, :subdirectory, :server_hostname, :user, :domain, :password, :cmk_secret_config, :custom_secret_config, :agent_arns, :mount_options, :authentication_type, :dns_ip_addresses, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf) SENSITIVE = [:password] include Aws::Structure end |
#user ⇒ String
Specifies the user name that can mount your SMB file server and has
permission to access the files and folders involved in your
transfer. This parameter applies only if AuthenticationType is set
to NTLM.
For information about choosing a user with the right level of access for your transfer, see Providing DataSync access to SMB file servers.
6714 6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 |
# File 'lib/aws-sdk-datasync/types.rb', line 6714 class UpdateLocationSmbRequest < Struct.new( :location_arn, :subdirectory, :server_hostname, :user, :domain, :password, :cmk_secret_config, :custom_secret_config, :agent_arns, :mount_options, :authentication_type, :dns_ip_addresses, :kerberos_principal, :kerberos_keytab, :kerberos_krb_5_conf) SENSITIVE = [:password] include Aws::Structure end |